/**
 * @file
 * VuoUsbVendor implementation.
 *
 * @copyright Copyright © 2012–2017 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "VuoUsbVendor.h"

#include "module.h"

#ifdef VUO_COMPILER
VuoModuleMetadata({
					 "title" : "VuoUsbVendor"
				 });
#endif


/**
 * Returns a string containing a verbal description of the specified USB vendor ID.
 *
 * The caller is responsible for freeing the returned string.
 *
 * Generated using:
 *
 *     curl http://www.usb.org/developers/tools/comp_dump | sort -n | perl -pe 's/([0-9]+)\|(.+)/else if (vendor == \1) vendorText = "\2";/g;'
 */
char *VuoUsbVendor_getText(uint32_t vendor)
{
	char *vendorText = NULL;
	if      (vendor ==    1) vendorText = "Kavi-EVAL";
	else if (vendor == 1000) vendorText = "EndPoints Inc.";
	else if (vendor == 1001) vendorText = "Thesys Microelectronics";
	else if (vendor == 1003) vendorText = "Atmel Corporation";
	else if (vendor == 1005) vendorText = "Mitel Corporation";
	else if (vendor == 1006) vendorText = "Mitsumi";
	else if (vendor == 1008) vendorText = "Hewlett Packard";
	else if (vendor == 1009) vendorText = "Genoa Technology";
	else if (vendor == 1010) vendorText = "Oak Technology, Inc";
	else if (vendor == 1011) vendorText = "Adaptec, Inc.";
	else if (vendor == 1012) vendorText = "Diebold, Inc.";
	else if (vendor == 1016) vendorText = "Epson Research Center";
	else if (vendor == 1017) vendorText = "KeyTronic Corp.";
	else if (vendor == 1019) vendorText = "OPTi Inc.";
	else if (vendor == 1020) vendorText = "Elitegroup Computer Systems";
	else if (vendor == 1021) vendorText = "Xilinx Inc.";
	else if (vendor == 1022) vendorText = "Farallon Comunications";
	else if (vendor == 1024) vendorText = "National Semiconductor";
	else if (vendor == 1026) vendorText = "Acer Labs Inc. (ALi)";
	else if (vendor == 1027) vendorText = "Future Technology Devices International Limited";
	else if (vendor == 1028) vendorText = "NCR Corporation";
	else if (vendor == 1029) vendorText = "Sand inSilicon";
	else if (vendor == 1031) vendorText = "Fujitsu Personal Systems, Inc.";
	else if (vendor == 1032) vendorText = "Quanta Computer Inc.";
	else if (vendor == 1033) vendorText = "NEC Corporation";
	else if (vendor == 1034) vendorText = "Eastman Kodak Company";
	else if (vendor == 1035) vendorText = "Weltrend Semiconductor";
	else if (vendor == 1037) vendorText = "VIA Technologies, Inc.";
	else if (vendor == 1038) vendorText = "MCCI";
	else if (vendor == 1041) vendorText = "Buffalo Melco, Inc.";
	else if (vendor == 1043) vendorText = "Leadtek Research Inc.";
	else if (vendor == 1044) vendorText = "Giga-Byte Technology Co., Ltd.";
	else if (vendor == 1046) vendorText = "Winbond Nuvoton Electronics Corp.";
	else if (vendor == 1050) vendorText = "Phoenix Technologies Ltd.";
	else if (vendor == 1054) vendorText = "Creative Labs";
	else if (vendor == 1057) vendorText = "Nokia Corporation";
	else if (vendor == 1058) vendorText = "ADI Systems Inc.";
	else if (vendor == 1059) vendorText = "CATC";
	else if (vendor == 1060) vendorText = "Microchip-SMSC";
	else if (vendor == 1061) vendorText = "Motorola Semiconductors HK, Ltd.";
	else if (vendor == 1062) vendorText = "Integrated Device Technology";
	else if (vendor == 1063) vendorText = "Motorola Electronics Taiwan Ltd.";
	else if (vendor == 1064) vendorText = "Advanced Gravis Computer Ltd.";
	else if (vendor == 1065) vendorText = "Cirrus Logic Inc.";
	else if (vendor == 1066) vendorText = "Ericsson Austrian, AG";
	else if (vendor == 1068) vendorText = "Innovative Semiconductors, Inc.";
	else if (vendor == 1071) vendorText = "Molex Inc.";
	else if (vendor == 1072) vendorText = "Fujitsu Component Limited";
	else if (vendor == 1073) vendorText = "ITAC Systems, Inc.";
	else if (vendor == 1074) vendorText = "Unisys Corp.";
	else if (vendor == 1077) vendorText = "Hyundai Electronics America";
	else if (vendor == 1078) vendorText = "Taugagreining HF";
	else if (vendor == 1080) vendorText = "Advanced Micro Devices";
	else if (vendor == 1085) vendorText = "Lexmark International Inc.";
	else if (vendor == 1086) vendorText = "LG Electronics USA Inc.";
	else if (vendor == 1088) vendorText = "EIZO NANAO CORPORATION";
	else if (vendor == 1090) vendorText = "Ericsson Inc.";
	else if (vendor == 1091) vendorText = "Gateway 2000";
	else if (vendor == 1094) vendorText = "NMB Technologies Corporation";
	else if (vendor == 1097) vendorText = "Eldim";
	else if (vendor == 1098) vendorText = "Shamrock Technology Co., Ltd.";
	else if (vendor == 1100) vendorText = "CCL/ITRI";
	else if (vendor == 1101) vendorText = "Siemens Nixdorf AG";
	else if (vendor == 1102) vendorText = "Alps Electric Co., Ltd.";
	else if (vendor == 1103) vendorText = "ThrustMaster, Inc.";
	else if (vendor == 1105) vendorText = "Texas Instruments";
	else if (vendor == 1106) vendorText = "Mitsubishi Electronics America, Inc.";
	else if (vendor == 1107) vendorText = "CMD Technology";
	else if (vendor == 1110) vendorText = "Analog Devices, Inc.";
	else if (vendor == 1111) vendorText = "Silicon Integrated Systems Corp.";
	else if (vendor == 1112) vendorText = "KYE Systems Corp.";
	else if (vendor == 1113) vendorText = "Adobe Systems, Inc.";
	else if (vendor == 1114) vendorText = "SONICblue Incorporated";
	else if (vendor == 1115) vendorText = "Renesas Electronics Corp.";
	else if (vendor == 1117) vendorText = "Nortel Networks";
	else if (vendor == 1118) vendorText = "Microsoft Corporation";
	else if (vendor == 1121) vendorText = "Primax Electronics";
	else if (vendor == 1123) vendorText = "EATON";
	else if (vendor == 1124) vendorText = "AMP/Tycoelectronics";
	else if (vendor == 1128) vendorText = "Wieson Technologies Co., Ltd.";
	else if (vendor == 1130) vendorText = "CHERRY GmbH";
	else if (vendor == 1131) vendorText = "American Megatrends";
	else if (vendor == 1132) vendorText = "Toshiba";
	else if (vendor == 1133) vendorText = "Logitech Inc.";
	else if (vendor == 1134) vendorText = "Behavior Tech Computer Corporation";
	else if (vendor == 1137) vendorText = "Philips Consumer Lifestyle BV";
	else if (vendor == 1138) vendorText = "Sun Microsystems";
	else if (vendor == 1139) vendorText = "Sanyo Information Business Co., Ltd.";
	else if (vendor == 1140) vendorText = "Sanyo Electric Co. Ltd.";
	else if (vendor == 1141) vendorText = "TECO Infor-ion System";
	else if (vendor == 1144) vendorText = "Connectix";
	else if (vendor == 1146) vendorText = "Semtech Corporation";
	else if (vendor == 1147) vendorText = "Silitek Corp.";
	else if (vendor == 1148) vendorText = "Dell Computer Corp.";
	else if (vendor == 1149) vendorText = "Kensington";
	else if (vendor == 1150) vendorText = "LSI Avago Corporation";
	else if (vendor == 1151) vendorText = "Plantronics, Inc.";
	else if (vendor == 1152) vendorText = "Toshiba America Info. Systems, Inc.";
	else if (vendor == 1154) vendorText = "Kyocera Corporation";
	else if (vendor == 1155) vendorText = "STMicroelectronics";
	else if (vendor == 1160) vendorText = "Cirque Corporation";
	else if (vendor == 1161) vendorText = "Foxconn / Hon Hai";
	else if (vendor == 1165) vendorText = "Integrated Technology Express";
	else if (vendor == 1165) vendorText = "Integrated Technology Express (ITE), Inc.";
	else if (vendor == 1169) vendorText = "Capetronic (Kaohsiung ) Corp.";
	else if (vendor == 1170) vendorText = "Samsung Semiconductor, Inc.";
	else if (vendor == 1174) vendorText = "Micron Electronics";
	else if (vendor == 1175) vendorText = "Smile International, Inc.";
	else if (vendor == 1177) vendorText = "Yamaha Corporation";
	else if (vendor == 1179) vendorText = "Curtis Connections";
	else if (vendor == 1181) vendorText = "VLSI Technology, Inc.";
	else if (vendor == 1183) vendorText = "Compaq Computer Corporation";
	else if (vendor == 1188) vendorText = "Hitachi, Ltd.";
	else if (vendor == 1189) vendorText = "Acer BenQ Peripherals Inc.";
	else if (vendor == 1190) vendorText = "Nokia Display Products";
	else if (vendor == 1191) vendorText = "Visioneer";
	else if (vendor == 1192) vendorText = "Multivideo Labs, Inc.";
	else if (vendor == 1193) vendorText = "Canon Inc.";
	else if (vendor == 1200) vendorText = "Nikon Corporation";
	else if (vendor == 1201) vendorText = "Pan International";
	else if (vendor == 1203) vendorText = "IBM Corporation";
	else if (vendor == 1204) vendorText = "Cypress Semiconductor";
	else if (vendor == 1205) vendorText = "ROHM Co., Ltd.";
	else if (vendor == 1207) vendorText = "Compal Electronics, Inc.";
	else if (vendor == 1208) vendorText = "Seiko Epson Corp.";
	else if (vendor == 1209) vendorText = "Rainbow Technologies, Inc.";
	else if (vendor == 1211) vendorText = "I-O Data Device, Inc.";
	else if (vendor == 1215) vendorText = "TDK Corporation";
	else if (vendor == 1221) vendorText = "Fujitsu Ltd.";
	else if (vendor == 1222) vendorText = "Toshiba America Electronic Components";
	else if (vendor == 1223) vendorText = "Micro Macro Technologies";
	else if (vendor == 1224) vendorText = "Konica Corporation";
	else if (vendor == 1226) vendorText = "Lite-On Technology Corp.";
	else if (vendor == 1227) vendorText = "FUJIFILM Photo Co., Ltd.";
	else if (vendor == 1228) vendorText = "Philips ST-Ericsson Semiconductors";
	else if (vendor == 1229) vendorText = "Tatung Company of America, Inc.";
	else if (vendor == 1230) vendorText = "ScanLogic Corporation";
	else if (vendor == 1231) vendorText = "Myson Century, Inc.";
	else if (vendor == 1233) vendorText = "ITT Cannon";
	else if (vendor == 1234) vendorText = "Altec Lansing Technologies, Inc.";
	else if (vendor == 1236) vendorText = "LSI Logic Corporation";
	else if (vendor == 1238) vendorText = "Mentor Graphics";
	else if (vendor == 1239) vendorText = "Oki Semiconductor";
	else if (vendor == 1240) vendorText = "Microchip Technology Inc.";
	else if (vendor == 1241) vendorText = "Holtek Semiconductor, Inc.";
	else if (vendor == 1242) vendorText = "Panasonic Corporation";
	else if (vendor == 1244) vendorText = "Huan Hsin Holdings Ltd.";
	else if (vendor == 1245) vendorText = "Sharp Corporation";
	else if (vendor == 1246) vendorText = "MindShare, Inc.";
	else if (vendor == 1247) vendorText = "Interlink Electronics";
	else if (vendor == 1249) vendorText = "Iiyama Corporation";
	else if (vendor == 1250) vendorText = "Exar Corporation";
	else if (vendor == 1254) vendorText = "Shuttle Technology Identiv SCM Microsystems";
	else if (vendor == 1255) vendorText = "Elo TouchSystems";
	else if (vendor == 1256) vendorText = "Samsung Electronics Co., Ltd.";
	else if (vendor == 1257) vendorText = "PC-Tel Inc.";
	else if (vendor == 1259) vendorText = "Northstar Systems, Inc";
	else if (vendor == 1260) vendorText = "Tokyo Electron Device Limited";
	else if (vendor == 1261) vendorText = "Annabooks";
	else if (vendor == 1265) vendorText = "Victor Company of Japan, Limited";
	else if (vendor == 1266) vendorText = "Chicony Electronics Co., Ltd.";
	else if (vendor == 1267) vendorText = "Elan Microelectronics Corportation";
	else if (vendor == 1271) vendorText = "Newnex Technology Corp.";
	else if (vendor == 1272) vendorText = "FuturePlus Systems";
	else if (vendor == 1273) vendorText = "Brother Industries, Ltd.";
	else if (vendor == 1274) vendorText = "Dallas Semiconductor";
	else if (vendor == 1275) vendorText = "Biostar Microtech Int'l Corp.";
	else if (vendor == 1276) vendorText = "SUNPLUS TECHNOLOGY CO., LTD.";
	else if (vendor == 1277) vendorText = "Soliton Systems K.K.";
	else if (vendor == 1278) vendorText = "PFU Limited";
	else if (vendor == 1279) vendorText = "E-CMOS Corp.";
	else if (vendor == 1281) vendorText = "Fujikura/DDK";
	else if (vendor == 1282) vendorText = "Acer, Inc.";
	else if (vendor == 1284) vendorText = "Hayes Microcomputer Products";
	else if (vendor == 1286) vendorText = "3Com Corporation";
	else if (vendor == 1287) vendorText = "Hosiden Corporation";
	else if (vendor == 1288) vendorText = "Clarion Co., Ltd.";
	else if (vendor == 1289) vendorText = "Aztech Systems Ltd";
	else if (vendor == 1293) vendorText = "Belkin Corporation";
	else if (vendor == 1295) vendorText = "KC Technology Inc.";
	else if (vendor == 1296) vendorText = "Sejin Electron Inc.";
	else if (vendor == 1300) vendorText = "FCI Electronics";
	else if (vendor == 1302) vendorText = "Longwell Electronics/Longwell Company";
	else if (vendor == 1303) vendorText = "Butterfly Communications";
	else if (vendor == 1304) vendorText = "EzKEY Corp.";
	else if (vendor == 1305) vendorText = "Star Micronics Co., LTD";
	else if (vendor == 1308) vendorText = "Shuttle Inc.";
	else if (vendor == 1309) vendorText = "American Power Conversion";
	else if (vendor == 1310) vendorText = "Scientific Atlanta, Inc.";
	else if (vendor == 1311) vendorText = "IO Systems Inc. fomerly Elite Electronics, Inc.";
	else if (vendor == 1312) vendorText = "Taiwan Semiconductor Manufacturing Co.";
	else if (vendor == 1314) vendorText = "ACON, Advanced-Connectek, Inc.";
	else if (vendor == 1315) vendorText = "ATEN GMBH";
	else if (vendor == 1316) vendorText = "Sola Electronics";
	else if (vendor == 1317) vendorText = "PLX Technology, Inc.";
	else if (vendor == 1318) vendorText = "Temic MHS S.A.";
	else if (vendor == 1319) vendorText = "ALTRA";
	else if (vendor == 1320) vendorText = "ATI Technologies, Inc.";
	else if (vendor == 1321) vendorText = "Aladdin Knowledge Systems";
	else if (vendor == 1322) vendorText = "Crescent Heart Software";
	else if (vendor == 1323) vendorText = "Tekom Technologies, Inc";
	else if (vendor == 1324) vendorText = "Canon Development Americas";
	else if (vendor == 1329) vendorText = "Wacom Technology Corp.";
	else if (vendor == 1330) vendorText = "Systech Corporation";
	else if (vendor == 1334) vendorText = "Welch Allyn Inc.";
	else if (vendor == 1335) vendorText = "Inventec Corporation";
	else if (vendor == 1336) vendorText = "Caldera International, Inc.";
	else if (vendor == 1337) vendorText = "Shyh Shiun Terminals Co. LTD";
	else if (vendor == 1338) vendorText = "Preh Werke Gmbh & Co. KG";
	else if (vendor == 1340) vendorText = "Institut of Microelectronic and Mechatronic Systems";
	else if (vendor == 1341) vendorText = "Silicon Architect";
	else if (vendor == 1342) vendorText = "Mobility Electronics";
	else if (vendor == 1343) vendorText = "Synopsys, Inc.";
	else if (vendor == 1344) vendorText = "UniAccess AB";
	else if (vendor == 1345) vendorText = "Sirf Technology, Inc";
	else if (vendor == 1347) vendorText = "ViewSonic Corporation";
	else if (vendor == 1349) vendorText = "Xirlink, Inc.";
	else if (vendor == 1350) vendorText = "Polaroid Corporation";
	else if (vendor == 1351) vendorText = "Anchor Chips Inc.";
	else if (vendor == 1356) vendorText = "Sony Corporation";
	else if (vendor == 1360) vendorText = "Fuji Xerox Co., Ltd.";
	else if (vendor == 1362) vendorText = "Philips Monitors";
	else if (vendor == 1363) vendorText = "VLSI Vision STMicroelectronics Imaging Division";
	else if (vendor == 1364) vendorText = "Dictaphone Corp.";
	else if (vendor == 1366) vendorText = "Asahi Kasei Microsystems Co., Ltd";
	else if (vendor == 1367) vendorText = "ATEN International Co. Ltd.";
	else if (vendor == 1369) vendorText = "Cadence Design Systems, Inc.";
	else if (vendor == 1373) vendorText = "Samsung Electro-Mechanics Co.";
	else if (vendor == 1374) vendorText = "CTX Opto-Electronics Corp.";
	else if (vendor == 1376) vendorText = "Interface Corporation";
	else if (vendor == 1378) vendorText = "Telex Communications Inc.";
	else if (vendor == 1379) vendorText = "Immersion Corporation";
	else if (vendor == 1380) vendorText = "Chinon Industries, Inc.";
	else if (vendor == 1381) vendorText = "Peracom Networks, Inc.";
	else if (vendor == 1382) vendorText = "Monterey International Corp.";
	else if (vendor == 1383) vendorText = "Xyratex";
	else if (vendor == 1386) vendorText = "WACOM Co., Ltd.";
	else if (vendor == 1388) vendorText = "Belkin Research & Development";
	else if (vendor == 1389) vendorText = "Eizo";
	else if (vendor == 1390) vendorText = "Elecom Co., Ltd.";
	else if (vendor == 1391) vendorText = "Korea Data Systems Co., Ltd.";
	else if (vendor == 1393) vendorText = "Interex, Inc.";
	else if (vendor == 1394) vendorText = "Conexant Systems, Inc.";
	else if (vendor == 1395) vendorText = "Zoran Corporation";
	else if (vendor == 1397) vendorText = "Philips Creative Display Solutions";
	else if (vendor == 1398) vendorText = "BAFO/Quality Computer Accessories";
	else if (vendor == 1403) vendorText = "Y-E Data, Inc.";
	else if (vendor == 1404) vendorText = "AVM GmbH";
	else if (vendor == 1405) vendorText = "Shark Multimedia Inc.";
	else if (vendor == 1406) vendorText = "Nintendo Co., Ltd.";
	else if (vendor == 1407) vendorText = "QuickShot Limited";
	else if (vendor == 1410) vendorText = "Roland Corporation";
	else if (vendor == 1411) vendorText = "Padix Co., Ltd.";
	else if (vendor == 1412) vendorText = "RATOC Systems, Inc.";
	else if (vendor == 1413) vendorText = "FlashPoint Technology, Inc.";
	else if (vendor == 1416) vendorText = "Sapien Design";
	else if (vendor == 1419) vendorText = "Siemens Infineon Technologies";
	else if (vendor == 1420) vendorText = "In Focus Systems";
	else if (vendor == 1421) vendorText = "Micrel Semiconductor";
	else if (vendor == 1422) vendorText = "Tripath Technology Inc.";
	else if (vendor == 1423) vendorText = "Alcor Micro, Corp.";
	else if (vendor == 1424) vendorText = "OMRON Corporation";
	else if (vendor == 1426) vendorText = "Exide Electronics";
	else if (vendor == 1429) vendorText = "Zoran Microelectronics Ltd.";
	else if (vendor == 1430) vendorText = "MicroTouch Systems Inc.";
	else if (vendor == 1432) vendorText = "Nigata Canotec Co., Inc.";
	else if (vendor == 1435) vendorText = "Iomega Corporation";
	else if (vendor == 1436) vendorText = "A-Trend Technology Co., Ltd.";
	else if (vendor == 1437) vendorText = "Advanced Input Devices";
	else if (vendor == 1438) vendorText = "Intelligent Instrumentation";
	else if (vendor == 1439) vendorText = "LaCie";
	else if (vendor == 1441) vendorText = "USC Corporation";
	else if (vendor == 1442) vendorText = "Fuji Film Microdevices Co. Ltd.";
	else if (vendor == 1443) vendorText = "ARC V Automation Inc.";
	else if (vendor == 1444) vendorText = "Ortek Technology, Inc.";
	else if (vendor == 1445) vendorText = "Sampo Technology Corp.";
	else if (vendor == 1446) vendorText = "Cisco Systems, Inc.";
	else if (vendor == 1447) vendorText = "Bose Corporation";
	else if (vendor == 1448) vendorText = "Spacetec IMC Corporation";
	else if (vendor == 1449) vendorText = "OmniVision Technologies, Inc.";
	else if (vendor == 1451) vendorText = "In-System Design";
	else if (vendor == 1452) vendorText = "Apple";
	else if (vendor == 1453) vendorText = "Y.C. Cable U.S.A., Inc";
	else if (vendor == 1454) vendorText = "Jing-Mold Enterprise Co., Ltd.";
	else if (vendor == 1456) vendorText = "Fountain Technologies, Inc";
	else if (vendor == 1457) vendorText = "First International Computer, Inc.";
	else if (vendor == 1460) vendorText = "LG Semicon Co., Ltd.";
	else if (vendor == 1461) vendorText = "Dialogic Corp";
	else if (vendor == 1462) vendorText = "Proxima Corporation";
	else if (vendor == 1463) vendorText = "Medianix Semiconductor, Inc.";
	else if (vendor == 1466) vendorText = "DigitalPersona, Inc.";
	else if (vendor == 1469) vendorText = "RAFI GmbH & Co. KG";
	else if (vendor == 1470) vendorText = "Tyco Electronics Corp., a TE Connectivity Ltd. company";
	else if (vendor == 1472) vendorText = "Keil Software";
	else if (vendor == 1473) vendorText = "Kawasaki Steel MegaChips Corporation";
	else if (vendor == 1474) vendorText = "Mediaphonics S.A.";
	else if (vendor == 1477) vendorText = "Digi International Inc.";
	else if (vendor == 1478) vendorText = "Qualcomm, Inc";
	else if (vendor == 1479) vendorText = "Qtronix Corp";
	else if (vendor == 1480) vendorText = "Foxlink Cheng Uei Precision Industry Co., Ltd.";
	else if (vendor == 1481) vendorText = "Semtech Corporation";
	else if (vendor == 1482) vendorText = "Ricoh Company Ltd.";
	else if (vendor == 1483) vendorText = "PowerVision Technologies Inc.";
	else if (vendor == 1484) vendorText = "ELSA AG";
	else if (vendor == 1485) vendorText = "Silicom LTD.";
	else if (vendor == 1486) vendorText = "SICAN Gmbh";
	else if (vendor == 1487) vendorText = "Sung Forn Co. LTD.";
	else if (vendor == 1488) vendorText = "Lunar Corporation";
	else if (vendor == 1489) vendorText = "Brainboxes Limited";
	else if (vendor == 1490) vendorText = "Wave Systems Corp.";
	else if (vendor == 1494) vendorText = "Philips Semiconductors, CICT";
	else if (vendor == 1495) vendorText = "Thomas and Betts";
	else if (vendor == 1496) vendorText = "Ultima Electronics Corp.";
	else if (vendor == 1497) vendorText = "Axiohm Transaction Solutions";
	else if (vendor == 1498) vendorText = "Microtek International Inc.";
	else if (vendor == 1499) vendorText = "Sun Corporation";
	else if (vendor == 1500) vendorText = "Lexar Media, Inc.";
	else if (vendor == 1501) vendorText = "Delta Electronics Inc.";
	else if (vendor == 1504) vendorText = "Symbol Technologies";
	else if (vendor == 1505) vendorText = "Syntek Design Technology Inc.";
	else if (vendor == 1507) vendorText = "Genesys Logic, Inc.";
	else if (vendor == 1508) vendorText = "Red Wing Corporation";
	else if (vendor == 1509) vendorText = "Fuji Electric FA Components & Systems Co. Ltd.";
	else if (vendor == 1510) vendorText = "Keithley Instruments";
	else if (vendor == 1513) vendorText = "Kawasaki Microelectronics America, Inc.";
	else if (vendor == 1515) vendorText = "FFC Limited";
	else if (vendor == 1516) vendorText = "COM21, Inc.";
	else if (vendor == 1518) vendorText = "Cytechinfo Inc.";
	else if (vendor == 1519) vendorText = "Anko Electronic Co., Ltd.";
	else if (vendor == 1520) vendorText = "Canopus Co., Ltd.";
	else if (vendor == 1522) vendorText = "Dexin Corporation, Ltd.";
	else if (vendor == 1523) vendorText = "PI Engineering, Inc";
	else if (vendor == 1525) vendorText = "Unixtar Technology Inc.";
	else if (vendor == 1526) vendorText = "AOC International";
	else if (vendor == 1527) vendorText = "RFC Distribution(s) PTE Ltd.";
	else if (vendor == 1529) vendorText = "Datalogic ADC PSC Scanning, Inc.";
	else if (vendor == 1530) vendorText = "Siemens Telecommunications Systems Limited";
	else if (vendor == 1532) vendorText = "Harman International";
	else if (vendor == 1533) vendorText = "STD Manufacturing Ltd.";
	else if (vendor == 1534) vendorText = "CHIC TECHNOLOGY CORP";
	else if (vendor == 1535) vendorText = "LeCroy Corporation";
	else if (vendor == 1536) vendorText = "Barco Display Systems";
	else if (vendor == 1537) vendorText = "Jazz Hipster Corporation";
	else if (vendor == 1538) vendorText = "Vista Imaging Inc.";
	else if (vendor == 1539) vendorText = "Novatek Microelectronics Corp.";
	else if (vendor == 1540) vendorText = "Jean Co, Ltd.";
	else if (vendor == 1542) vendorText = "Royal Information Electronics Co., Ltd.";
	else if (vendor == 1543) vendorText = "Bridge Information Co., Ltd.";
	else if (vendor == 1545) vendorText = "SMK Manufacturing Inc.";
	else if (vendor == 1546) vendorText = "Worthington Data Solutions, Inc.";
	else if (vendor == 1547) vendorText = "Solid Year Co., Ltd.";
	else if (vendor == 1548) vendorText = "EEH Datalink Gmbh";
	else if (vendor == 1550) vendorText = "Transmonde Technologies, Inc.";
	else if (vendor == 1551) vendorText = "Joinsoon Electronics Mfg. Co., Ltd.";
	else if (vendor == 1553) vendorText = "Totoku Electric Co., LTD.";
	else if (vendor == 1555) vendorText = "TransAct Technologies Incorporated";
	else if (vendor == 1556) vendorText = "Bio-Rad Laboratories";
	else if (vendor == 1558) vendorText = "Future Techno Designs PVT. LTD.";
	else if (vendor == 1560) vendorText = "Chia Shin Technology Corp.";
	else if (vendor == 1561) vendorText = "Seiko Instruments Inc.";
	else if (vendor == 1562) vendorText = "Veridicom";
	else if (vendor == 1564) vendorText = "Act Labs, Ltd.";
	else if (vendor == 1565) vendorText = "Quatech, Inc.";
	else if (vendor == 1566) vendorText = "Nissei Electric Co.";
	else if (vendor == 1568) vendorText = "Alaris, Inc.";
	else if (vendor == 1569) vendorText = "ODU-Steckverbindungssysteme GmbH and Co. KG";
	else if (vendor == 1571) vendorText = "Littelfuse, Inc.";
	else if (vendor == 1572) vendorText = "Apex PC Solutions, Inc.";
	else if (vendor == 1574) vendorText = "Nippon Systems Development Co., Ltd.";
	else if (vendor == 1577) vendorText = "Zida Technologies Limited";
	else if (vendor == 1578) vendorText = "MosArt ProVision Semiconductor Corp.";
	else if (vendor == 1579) vendorText = "Greatlink Electronics Taiwan  Ltd.";
	else if (vendor == 1581) vendorText = "Taiwan Tai-Hao Enterprises Co. Ltd.";
	else if (vendor == 1582) vendorText = "JPC Mainsuper Enterprises Co., Ltd.";
	else if (vendor == 1583) vendorText = "Sin Sheng Terminal & Machine Inc.";
	else if (vendor == 1588) vendorText = "Crucial Technology/Micron Semiconductor Products";
	else if (vendor == 1590) vendorText = "Sierra Imaging, Inc.";
	else if (vendor == 1592) vendorText = "Avision, Inc.";
	else if (vendor == 1593) vendorText = "Chrontel, Inc.";
	else if (vendor == 1594) vendorText = "Techwin Corporation";
	else if (vendor == 1597) vendorText = "Fong Kai Industrial Co., Ltd.";
	else if (vendor == 1599) vendorText = "New Technology Cable Ltd.";
	else if (vendor == 1600) vendorText = "Hitex Development Tools";
	else if (vendor == 1601) vendorText = "Woods Industries, Inc.";
	else if (vendor == 1602) vendorText = "VIA Medical Corporation";
	else if (vendor == 1604) vendorText = "TEAC Corporation";
	else if (vendor == 1605) vendorText = "Who Vision Systems, Inc.";
	else if (vendor == 1608) vendorText = "Inside Out Networks";
	else if (vendor == 1611) vendorText = "Analog Devices, Inc. Development Tools";
	else if (vendor == 1612) vendorText = "Ji-Haw Industrial Co., Ltd";
	else if (vendor == 1614) vendorText = "Suyin Corporation";
	else if (vendor == 1615) vendorText = "WIBU-Systems AG";
	else if (vendor == 1617) vendorText = "Likom Technology Sdn. Bhd.";
	else if (vendor == 1618) vendorText = "Stargate Solutions, Inc.";
	else if (vendor == 1620) vendorText = "Granite Microsystems, Inc.";
	else if (vendor == 1621) vendorText = "Space Shuttle Hi-Fi Wire and Cable Industry Co, Ltd.";
	else if (vendor == 1622) vendorText = "Glory Mark Electronic Ltd.";
	else if (vendor == 1623) vendorText = "Tekcon Electronics Corp.";
	else if (vendor == 1624) vendorText = "Sigma Designs, Inc.";
	else if (vendor == 1626) vendorText = "Optoelectronics Co., Ltd.";
	else if (vendor == 1630) vendorText = "Silicon Graphics";
	else if (vendor == 1631) vendorText = "Good Way Technology Co., Ltd. & GWC technology Inc";
	else if (vendor == 1632) vendorText = "TSAY-E (BVI) International Inc.";
	else if (vendor == 1633) vendorText = "Hamamatsu Photonics K.K.";
	else if (vendor == 1635) vendorText = "Topmax Electronic Co., Ltd.";
	else if (vendor == 1640) vendorText = "WordWand";
	else if (vendor == 1641) vendorText = "Oce Printing Systems GmbH";
	else if (vendor == 1642) vendorText = "Total Technologies, Ltd.";
	else if (vendor == 1643) vendorText = "Intermart Systems, Inc.";
	else if (vendor == 1645) vendorText = "Entrega Technologies Inc.";
	else if (vendor == 1646) vendorText = "Acer Semiconductor America, Inc.";
	else if (vendor == 1647) vendorText = "SigmaTel, Inc.";
	else if (vendor == 1650) vendorText = "Labtec Inc.";
	else if (vendor == 1652) vendorText = "Key Mouse Electronic (KME) Enterprise Co., Ltd.";
	else if (vendor == 1653) vendorText = "DrayTek Corp.";
	else if (vendor == 1654) vendorText = "Teles AG";
	else if (vendor == 1655) vendorText = "Aiwa Co., Ltd.";
	else if (vendor == 1656) vendorText = "ACARD Technology Corp.";
	else if (vendor == 1659) vendorText = "Prolific Technology, Inc.";
	else if (vendor == 1660) vendorText = "Efficient Networks, Inc.";
	else if (vendor == 1661) vendorText = "Hohner Corp.";
	else if (vendor == 1662) vendorText = "Intermec Technologies (S) Pte Ltd.";
	else if (vendor == 1663) vendorText = "Virata Ltd.";
	else if (vendor == 1664) vendorText = "Avance Logic Realtek Semiconductor Corp., CPP Div.";
	else if (vendor == 1665) vendorText = "Siemens Information and Communication Products";
	else if (vendor == 1669) vendorText = "ISDN*tek";
	else if (vendor == 1670) vendorText = "Minolta Co., Ltd.";
	else if (vendor == 1674) vendorText = "Pertech Inc.";
	else if (vendor == 1675) vendorText = "Potrans International, Inc.";
	else if (vendor == 1680) vendorText = "Golden Bridge Electech Inc.";
	else if (vendor == 1683) vendorText = "Hagiwara Sys-Com Co., Ltd.";
	else if (vendor == 1684) vendorText = "Lego Group";
	else if (vendor == 1688) vendorText = "Chuntex (CTX)";
	else if (vendor == 1689) vendorText = "Tektronix, Inc.";
	else if (vendor == 1690) vendorText = "Askey Computer Corporation";
	else if (vendor == 1691) vendorText = "Technicolor Thomson Consumer Electronics SA";
	else if (vendor == 1693) vendorText = "Hughes Network Systems";
	else if (vendor == 1694) vendorText = "Welcat Inc.";
	else if (vendor == 1698) vendorText = "Topro Technology Inc.";
	else if (vendor == 1699) vendorText = "Saitek PLC";
	else if (vendor == 1700) vendorText = "Xiamen Doowell Electron Co., Ltd.";
	else if (vendor == 1701) vendorText = "Divio";
	else if (vendor == 1703) vendorText = "MicroStore, Inc.";
	else if (vendor == 1705) vendorText = "Westell";
	else if (vendor == 1706) vendorText = "Sysgration Ltd.";
	else if (vendor == 1708) vendorText = "Fujitsu Laboratories of America, Inc.";
	else if (vendor == 1709) vendorText = "Greatland Electronics Taiwan Ltd.";
	else if (vendor == 1710) vendorText = "Eurofins Testronic Digital Testing Belgium";
	else if (vendor == 1711) vendorText = "Harting, Inc. of North America";
	else if (vendor == 1714) vendorText = "N*ABLE Technologies, Inc.";
	else if (vendor == 1720) vendorText = "Pixela Corporation";
	else if (vendor == 1721) vendorText = "Alcatel";
	else if (vendor == 1722) vendorText = "Smooth Cord & Connector Co., Ltd.";
	else if (vendor == 1723) vendorText = "EDA Inc.";
	else if (vendor == 1724) vendorText = "Oki Data Corporation";
	else if (vendor == 1725) vendorText = "AGFA-Gevaert NV";
	else if (vendor == 1726) vendorText = "AME Optimedia Asia Microelectronic Development, Inc.";
	else if (vendor == 1727) vendorText = "Leoco Corporation";
	else if (vendor == 1732) vendorText = "Bizlink Technology, Inc.";
	else if (vendor == 1733) vendorText = "Hagenuk, GmbH";
	else if (vendor == 1734) vendorText = "Infowave Software Inc.";
	else if (vendor == 1736) vendorText = "SIIG, Inc.";
	else if (vendor == 1737) vendorText = "Taxan (Europe) Ltd.";
	else if (vendor == 1738) vendorText = "Newer Technology, Inc.";
	else if (vendor == 1739) vendorText = "Synaptics Inc.";
	else if (vendor == 1740) vendorText = "Terayon Communication Systems";
	else if (vendor == 1741) vendorText = "Keyspan";
	else if (vendor == 1744) vendorText = "Traveling Software, Inc.";
	else if (vendor == 1745) vendorText = "Daewoo Electronics Co Ltd";
	else if (vendor == 1747) vendorText = "Mitsubishi Electric Corporation";
	else if (vendor == 1748) vendorText = "Cisco Systems";
	else if (vendor == 1749) vendorText = "Toshiba America Electronic Components, Inc.";
	else if (vendor == 1750) vendorText = "Aashima Technology B.V.";
	else if (vendor == 1751) vendorText = "Network Computing Devices (NCD)";
	else if (vendor == 1752) vendorText = "Technical Marketing Research, Inc.";
	else if (vendor == 1754) vendorText = "Phoenixtec Power Co., Ltd.";
	else if (vendor == 1755) vendorText = "Paradyne";
	else if (vendor == 1756) vendorText = "Compeye Corporation";
	else if (vendor == 1758) vendorText = "Heisei Technology Co., Ltd.";
	else if (vendor == 1760) vendorText = "Multi-Tech Systems, Inc.";
	else if (vendor == 1761) vendorText = "ADS Technologies, Inc.";
	else if (vendor == 1764) vendorText = "Alcatel Microelectronics";
	else if (vendor == 1766) vendorText = "Tiger Jet Network, Inc.";
	else if (vendor == 1771) vendorText = "PC Expert Tech. Co., Ltd.";
	else if (vendor == 1775) vendorText = "I.A.C. Geometrische Ingenieurs B.V.";
	else if (vendor == 1776) vendorText = "T.N.C Industrial Co., Ltd.";
	else if (vendor == 1777) vendorText = "Opcode Systems Inc.";
	else if (vendor == 1778) vendorText = "Emine Technology Company";
	else if (vendor == 1782) vendorText = "Wintrend Technology Co., Ltd.";
	else if (vendor == 1786) vendorText = "HSD S.r.L";
	else if (vendor == 1788) vendorText = "Motorola Semiconductor Products Sector/US";
	else if (vendor == 1789) vendorText = "Boston Acoustics";
	else if (vendor == 1790) vendorText = "Gallant Computer, Inc.";
	else if (vendor == 1793) vendorText = "Supercomal Wire & Cable SDN. BHD.";
	else if (vendor == 1795) vendorText = "Bencent Tzeng Bvtech Industry Inc.";
	else if (vendor == 1797) vendorText = "NKK Corporation";
	else if (vendor == 1798) vendorText = "Ariel Corporation";
	else if (vendor == 1800) vendorText = "Putercom Co., Ltd.";
	else if (vendor == 1801) vendorText = "SSL";
	else if (vendor == 1802) vendorText = "Oki Electric Industry Co., Ltd.";
	else if (vendor == 1805) vendorText = "Comoss Electronic Co., Ltd.";
	else if (vendor == 1806) vendorText = "Excel Cell Electronic Co., Ltd.";
	else if (vendor == 1808) vendorText = "Connect Tech Inc.";
	else if (vendor == 1809) vendorText = "Magic Control Technology Corp.";
	else if (vendor == 1811) vendorText = "Interval Research Corp.";
	else if (vendor == 1815) vendorText = "ZNK Corporation";
	else if (vendor == 1816) vendorText = "Imation Corp.";
	else if (vendor == 1817) vendorText = "Tremon Enterprised Co., Ltd.";
	else if (vendor == 1820) vendorText = "Xionics Document Technologies, Inc.";
	else if (vendor == 1821) vendorText = "Dialogic Eicon Networks Corporation";
	else if (vendor == 1822) vendorText = "Ariston Technologies";
	else if (vendor == 1827) vendorText = "Centillium Communications Corporation";
	else if (vendor == 1830) vendorText = "Vanguard International Semiconductor-America";
	else if (vendor == 1838) vendorText = "Sunix Co., Ltd.";
	else if (vendor == 1841) vendorText = "SusTeen, Inc.";
	else if (vendor == 1842) vendorText = "Goldfull Electronics & Telecommunications Corp.";
	else if (vendor == 1843) vendorText = "ViewQuest Technologies, Inc.";
	else if (vendor == 1844) vendorText = "LASAT Communications A/S";
	else if (vendor == 1846) vendorText = "Lorom Industrial Co., Ltd.";
	else if (vendor == 1848) vendorText = "Mad Catz, Inc.";
	else if (vendor == 1850) vendorText = "Chaplet Systems, Inc.";
	else if (vendor == 1851) vendorText = "Suncom Technologies";
	else if (vendor == 1859) vendorText = "BBnig und Kallenbach oHG";
	else if (vendor == 1861) vendorText = "Syntech Information Co., Ltd.";
	else if (vendor == 1862) vendorText = "ONKYO Corporation";
	else if (vendor == 1863) vendorText = "Labway Corporation";
	else if (vendor == 1864) vendorText = "Strong Man Enterprise Co., Ltd.";
	else if (vendor == 1865) vendorText = "EVer Electronics Corp.";
	else if (vendor == 1866) vendorText = "Ming Fortune Industry Co., Ltd.";
	else if (vendor == 1867) vendorText = "Polestar Tech. Corp.";
	else if (vendor == 1868) vendorText = "C-C-C Group PLC";
	else if (vendor == 1869) vendorText = "Micronas GmbH";
	else if (vendor == 1870) vendorText = "Digital Stream Corporation";
	else if (vendor == 1877) vendorText = "Aureal Semiconductor";
	else if (vendor == 1879) vendorText = "Network Technologies, Inc.";
	else if (vendor == 1883) vendorText = "Sophisticated Circuits, Inc.";
	else if (vendor == 1891) vendorText = "M-Audio";
	else if (vendor == 1892) vendorText = "Cyber Power Systems, Inc.";
	else if (vendor == 1893) vendorText = "X-Rite Incorporated";
	else if (vendor == 1894) vendorText = "Jess-Link Products Co., Ltd. (JPC)";
	else if (vendor == 1895) vendorText = "Tokheim Corporation";
	else if (vendor == 1896) vendorText = "Camtel Technology Corp.";
	else if (vendor == 1897) vendorText = "SURECOM Technology Corp.";
	else if (vendor == 1898) vendorText = "Smart Technology Enablers, Inc.";
	else if (vendor == 1899) vendorText = "HID Global GmbH";
	else if (vendor == 1900) vendorText = "Partner Tech";
	else if (vendor == 1901) vendorText = "Denso Corporation";
	else if (vendor == 1902) vendorText = "Kuan Tech Enterprise Co., Ltd.";
	else if (vendor == 1903) vendorText = "Jhen Vei Electronic Co., Ltd.";
	else if (vendor == 1904) vendorText = "Welch Allyn, Inc - Medical Division";
	else if (vendor == 1908) vendorText = "AmTRAN Technology Co., Ltd.";
	else if (vendor == 1909) vendorText = "Longshine Electronics Corp.";
	else if (vendor == 1910) vendorText = "Inalways Corporation";
	else if (vendor == 1911) vendorText = "Comda Advanced Technology Corporation";
	else if (vendor == 1912) vendorText = "Volex, Inc.";
	else if (vendor == 1913) vendorText = "Fairchild Semiconductor";
	else if (vendor == 1914) vendorText = "Sankyo Seiki Mfg. Co., Ltd.";
	else if (vendor == 1915) vendorText = "Linksys";
	else if (vendor == 1916) vendorText = "Forward Electronics Co., Ltd.";
	else if (vendor == 1919) vendorText = "Well Excellent and Most Corp.";
	else if (vendor == 1921) vendorText = "SanDisk Corporation";
	else if (vendor == 1922) vendorText = "Trackerball";
	else if (vendor == 1929) vendorText = "Logitec";
	else if (vendor == 1932) vendorText = "GTCO CalComp Peripherals";
	else if (vendor == 1934) vendorText = "BRINCOM";
	else if (vendor == 1936) vendorText = "Pro-Image Manufacturing Co., Ltd";
	else if (vendor == 1937) vendorText = "Copartner Technology Corporation";
	else if (vendor == 1938) vendorText = "Axis Communications AB";
	else if (vendor == 1939) vendorText = "Wha Yu Industrial Co., Ltd.";
	else if (vendor == 1940) vendorText = "ABL Electronics Corporation";
	else if (vendor == 1941) vendorText = "SiCore Systems, Inc.";
	else if (vendor == 1942) vendorText = "Certicom Corp.";
	else if (vendor == 1943) vendorText = "Grandtech Semiconductor Corporation";
	else if (vendor == 1947) vendorText = "Sagem";
	else if (vendor == 1949) vendorText = "Alfadata Computer Corp.";
	else if (vendor == 1954) vendorText = "National Technical Systems";
	else if (vendor == 1955) vendorText = "ONNTO Corp.";
	else if (vendor == 1956) vendorText = "Be Incorporated";
	else if (vendor == 1958) vendorText = "ADMtek Incorporated";
	else if (vendor == 1962) vendorText = "corega K.K.";
	else if (vendor == 1963) vendorText = "Freecom Computer Peripherals";
	else if (vendor == 1969) vendorText = "IMP, Inc.";
	else if (vendor == 1970) vendorText = "Motorola BCS";
	else if (vendor == 1971) vendorText = "Plustek, Inc.";
	else if (vendor == 1972) vendorText = "Olympus Optical Co., Ltd.";
	else if (vendor == 1973) vendorText = "Mega World International Ltd.";
	else if (vendor == 1974) vendorText = "Marubun Corp.";
	else if (vendor == 1975) vendorText = "TIME Interconnect Ltd.";
	else if (vendor == 1976) vendorText = "AboCom Systems, Inc.";
	else if (vendor == 1980) vendorText = "Canon Computer Sytems, Inc.";
	else if (vendor == 1981) vendorText = "Webgear Inc.";
	else if (vendor == 1982) vendorText = "Veridicom";
	else if (vendor == 1984) vendorText = "Code Mercenaries GmbH";
	else if (vendor == 1988) vendorText = "Datafab Systems Inc.";
	else if (vendor == 1989) vendorText = "APG Cash Drawer";
	else if (vendor == 1990) vendorText = "ShareWave, Inc.";
	else if (vendor == 1991) vendorText = "Powertech Industrial Co., Ltd.";
	else if (vendor == 1992) vendorText = "B.U.G., Inc.";
	else if (vendor == 1993) vendorText = "Allied Telesyn International";
	else if (vendor == 1994) vendorText = "AVerMedia Technologies, Inc.";
	else if (vendor == 1996) vendorText = "LIWANLI Innovation Carry Technology Co., Ltd.";
	else if (vendor == 1999) vendorText = "Casio Computer Co., Ltd.";
	else if (vendor == 2001) vendorText = "D-Link Corporation";
	else if (vendor == 2002) vendorText = "Aptio Products Inc.";
	else if (vendor == 2003) vendorText = "Cyberdata Corp.";
	else if (vendor == 2007) vendorText = "GCC Technologies, Inc.";
	else if (vendor == 2010) vendorText = "Arasan Chip Systems Inc.";
	else if (vendor == 2015) vendorText = "David Electronics Company, Ltd.";
	else if (vendor == 2018) vendorText = "Elmeg GmbH and Co., Ltd.";
	else if (vendor == 2019) vendorText = "Planex Communications, Inc.";
	else if (vendor == 2020) vendorText = "Movado Enterprise Co., Ltd.";
	else if (vendor == 2021) vendorText = "QPS, Inc.";
	else if (vendor == 2022) vendorText = "Allied Cable Corporation";
	else if (vendor == 2023) vendorText = "Mirvo Toys, Inc.";
	else if (vendor == 2024) vendorText = "Labsystems";
	else if (vendor == 2027) vendorText = "Double-H Technology Co., Ltd.";
	else if (vendor == 2028) vendorText = "Taiyo Electric Wire & Cable Co., Ltd.";
	else if (vendor == 2038) vendorText = "Circuit Assembly Corp.";
	else if (vendor == 2039) vendorText = "Century Corporation";
	else if (vendor == 2041) vendorText = "Dotop Technology, Inc.";
	else if (vendor == 2049) vendorText = "Mag-Tek";
	else if (vendor == 2050) vendorText = "Mako Technologies, LLC";
	else if (vendor == 2051) vendorText = "Zoom Telephonics, Inc.";
	else if (vendor == 2057) vendorText = "Genicom Corp.";
	else if (vendor == 2058) vendorText = "Evermuch Technology Co., Ltd.";
	else if (vendor == 2061) vendorText = "TECO Image Systems Co., Ltd.";
	else if (vendor == 2064) vendorText = "Personal Communication Systems, Inc.";
	else if (vendor == 2067) vendorText = "Mattel, Inc.";
	else if (vendor == 2075) vendorText = "Indigita Corporation";
	else if (vendor == 2076) vendorText = "Mipsys";
	else if (vendor == 2078) vendorText = "AlphaSmart, Inc.";
	else if (vendor == 2082) vendorText = "REUDO Corporation";
	else if (vendor == 2085) vendorText = "GC Protronics";
	else if (vendor == 2086) vendorText = "Data Transit";
	else if (vendor == 2087) vendorText = "BroadLogic, Inc.";
	else if (vendor == 2088) vendorText = "Sato Corporation";
	else if (vendor == 2089) vendorText = "DirecTV Broadband";
	else if (vendor == 2093) vendorText = "Handspring Visor";
	else if (vendor == 2096) vendorText = "Palm Inc.";
	else if (vendor == 2098) vendorText = "Kouwell Electronics Corp.";
	else if (vendor == 2099) vendorText = "Source Corporation";
	else if (vendor == 2101) vendorText = "Action Star Enterprise Co., Ltd.";
	else if (vendor == 2105) vendorText = "Samsung Aerospace Industries Ltd.";
	else if (vendor == 2106) vendorText = "Accton Technology Corporation";
	else if (vendor == 2112) vendorText = "Argosy Research Inc.";
	else if (vendor == 2113) vendorText = "Rioport.com Inc.";
	else if (vendor == 2116) vendorText = "Welland Industrial Co., Ltd.";
	else if (vendor == 2118) vendorText = "NETGEAR, Inc.";
	else if (vendor == 2122) vendorText = "Wipro Limited";
	else if (vendor == 2125) vendorText = "Minton Optic Industry Co., Ltd.";
	else if (vendor == 2128) vendorText = "Fast Point Technologies, Inc.";
	else if (vendor == 2129) vendorText = "Macronix International Co., Ltd.";
	else if (vendor == 2130) vendorText = "CSEM";
	else if (vendor == 2135) vendorText = "Gerber Scientific Products, Inc.";
	else if (vendor == 2136) vendorText = "Hitachi Maxell Ltd.";
	else if (vendor == 2137) vendorText = "Minolta Systems Laboratory, Inc.";
	else if (vendor == 2138) vendorText = "Xircom";
	else if (vendor == 2146) vendorText = "Teletrol Systems, Inc.";
	else if (vendor == 2147) vendorText = "Filanet Corporation";
	else if (vendor == 2151) vendorText = "Data Translation, Inc.";
	else if (vendor == 2154) vendorText = "Emagic Soft-und Hardware Gmbh";
	else if (vendor == 2158) vendorText = "System TALKS Inc.";
	else if (vendor == 2159) vendorText = "MEC IMEX INC/HPT";
	else if (vendor == 2160) vendorText = "Metricom";
	else if (vendor == 2163) vendorText = "Xpeed Inc.";
	else if (vendor == 2164) vendorText = "A-Tec Subsystem, Inc.";
	else if (vendor == 2169) vendorText = "Comtrol Corporation";
	else if (vendor == 2172) vendorText = "ADESSO/Kbtek America Inc.";
	else if (vendor == 2173) vendorText = "JATON Corporation";
	else if (vendor == 2174) vendorText = "Fujitsu Computer Products of America";
	else if (vendor == 2175) vendorText = "QualCore Logic Inc";
	else if (vendor == 2176) vendorText = "APT Technologies Inc.";
	else if (vendor == 2179) vendorText = "Recording Industry Association of America (RIAA)";
	else if (vendor == 2181) vendorText = "Boca Research, Inc.";
	else if (vendor == 2182) vendorText = "XAC Automation Corp.";
	else if (vendor == 2183) vendorText = "Hannstar Electronics Corp.";
	else if (vendor == 2194) vendorText = "DioGraphy Inc.";
	else if (vendor == 2204) vendorText = "United Technologies Research Cntr.";
	else if (vendor == 2205) vendorText = "Icron Technologies Corporation";
	else if (vendor == 2206) vendorText = "NST Co., Ltd.";
	else if (vendor == 2213) vendorText = "e9 Inc.";
	else if (vendor == 2216) vendorText = "Andrea Electronics";
	else if (vendor == 2222) vendorText = "Mace Group, Inc.";
	else if (vendor == 2228) vendorText = "Sorenson Vision, Inc.";
	else if (vendor == 2232) vendorText = "J. Gordon Electronic Design, Inc.";
	else if (vendor == 2233) vendorText = "Tandy RadioShack Corporation";
	else if (vendor == 2235) vendorText = "Texas Instruments Japan";
	else if (vendor == 2237) vendorText = "Citizen Watch Co., Ltd.";
	else if (vendor == 2238) vendorText = "Meilenstein GmbH";
	else if (vendor == 2244) vendorText = "Proxim, Inc.";
	else if (vendor == 2247) vendorText = "TAI TWUN ENTERPRISE CO., LTD.";
	else if (vendor == 2248) vendorText = "2Wire, Inc";
	else if (vendor == 2249) vendorText = "Nippon Telegraph and Telephone Corp.";
	else if (vendor == 2250) vendorText = "AIPTEK International Inc.";
	else if (vendor == 2253) vendorText = "Jue Hsun Ind. Corp.";
	else if (vendor == 2254) vendorText = "Long Well Electronics Corp.";
	else if (vendor == 2255) vendorText = "Productivity Enhancement Products";
	else if (vendor == 2259) vendorText = "Virtual Ink";
	else if (vendor == 2260) vendorText = "Siemens PC Systems";
	else if (vendor == 2265) vendorText = "Increment P Corporation";
	else if (vendor == 2269) vendorText = "Billionton Systems, Inc.";
	else if (vendor == 2271) vendorText = "Spyrus Inc.";
	else if (vendor == 2276) vendorText = "Pioneer Corporation";
	else if (vendor == 2277) vendorText = "LITRONIC";
	else if (vendor == 2278) vendorText = "Gemalto SA";
	else if (vendor == 2279) vendorText = "PAN-INTERNATIONAL WIRE & CABLE (M) SDN BHD";
	else if (vendor == 2280) vendorText = "Integrated Memory Logic";
	else if (vendor == 2281) vendorText = "Extended Systems, Inc.";
	else if (vendor == 2282) vendorText = "Ericsson Inc., Blue Ridge Labs";
	else if (vendor == 2284) vendorText = "M-Systems Flash Disk Pioneers";
	else if (vendor == 2286) vendorText = "CCSI/HESSO";
	else if (vendor == 2288) vendorText = "CardScan Inc.";
	else if (vendor == 2289) vendorText = "CTI Electronics Corporation";
	else if (vendor == 2293) vendorText = "SYSTEC Co., Ltd.";
	else if (vendor == 2294) vendorText = "Logic 3 International Limited";
	else if (vendor == 2296) vendorText = "Keen Top International Enterprise Co., Ltd.";
	else if (vendor == 2297) vendorText = "Wipro Technologies";
	else if (vendor == 2298) vendorText = "CAERE";
	else if (vendor == 2299) vendorText = "Socket Communications";
	else if (vendor == 2300) vendorText = "Sicon Cable Technology Co. Ltd.";
	else if (vendor == 2301) vendorText = "Digianswer A/S";
	else if (vendor == 2303) vendorText = "AuthenTec, Inc.";
	else if (vendor == 2305) vendorText = "VST Technologies";
	else if (vendor == 2310) vendorText = "FARADAY Technology Corp.";
	else if (vendor == 2313) vendorText = "Audio-Technica Corp.";
	else if (vendor == 2314) vendorText = "Trumpion Microelectronics Inc";
	else if (vendor == 2315) vendorText = "Neurosmith";
	else if (vendor == 2316) vendorText = "Silicon Motion, Inc. - Taiwan";
	else if (vendor == 2317) vendorText = "MULTIPORT Computer Vertriebs GmbH";
	else if (vendor == 2318) vendorText = "Shining Technology, Inc.";
	else if (vendor == 2319) vendorText = "Fujitsu Devices Inc.";
	else if (vendor == 2320) vendorText = "Alation Systems, Inc.";
	else if (vendor == 2321) vendorText = "Philips Speech Processing";
	else if (vendor == 2322) vendorText = "Voquette, Inc.";
	else if (vendor == 2323) vendorText = "Asante' Technologies, Inc.";
	else if (vendor == 2325) vendorText = "GlobeSpan, Inc.";
	else if (vendor == 2327) vendorText = "SmartDisk Corporation";
	else if (vendor == 2334) vendorText = "Garmin International";
	else if (vendor == 2336) vendorText = "Echelon Co.";
	else if (vendor == 2337) vendorText = "GoHubs, inc.";
	else if (vendor == 2338) vendorText = "Dymo Corporation";
	else if (vendor == 2339) vendorText = "IC Media Corporation";
	else if (vendor == 2340) vendorText = "Xerox Corporation";
	else if (vendor == 2343) vendorText = "Summus, Ltd.";
	else if (vendor == 2344) vendorText = "Oxford Semiconductor Ltd.";
	else if (vendor == 2345) vendorText = "American Biometric Company";
	else if (vendor == 2346) vendorText = "Toshiba Information & Industrial Sys. And Services";
	else if (vendor == 2347) vendorText = "Sena Technologies, Inc.";
	else if (vendor == 2352) vendorText = "Toshiba Corporation";
	else if (vendor == 2353) vendorText = "Harmonic Data Systems Ltd.";
	else if (vendor == 2354) vendorText = "Crescentec Corporation";
	else if (vendor == 2355) vendorText = "Quantum Corp.";
	else if (vendor == 2356) vendorText = "Netcom Systems";
	else if (vendor == 2361) vendorText = "Lumberg, Inc.";
	else if (vendor == 2362) vendorText = "Pixart Imaging, Inc.";
	else if (vendor == 2363) vendorText = "Plextor LLC";
	else if (vendor == 2365) vendorText = "InnoSync, Inc.";
	else if (vendor == 2366) vendorText = "J.S.T. Mfg. Co., Ltd.";
	else if (vendor == 2367) vendorText = "OLYMPIA Telecom Vertriebs GmbH";
	else if (vendor == 2368) vendorText = "Japan Storage Battery Co., Ltd.";
	else if (vendor == 2369) vendorText = "Photobit Corporation";
	else if (vendor == 2370) vendorText = "i2Go.com, LLC";
	else if (vendor == 2371) vendorText = "HCL Technologies Ltd.";
	else if (vendor == 2372) vendorText = "KORG, Inc.";
	else if (vendor == 2373) vendorText = "PASCO Scientific";
	else if (vendor == 2381) vendorText = "Cable Television Laboratories";
	else if (vendor == 2385) vendorText = "Kingston Technology Company";
	else if (vendor == 2388) vendorText = "RPM Systems Corporation";
	else if (vendor == 2389) vendorText = "NVIDIA";
	else if (vendor == 2390) vendorText = "BSquare Corporation";
	else if (vendor == 2391) vendorText = "Agilent Technologies, Inc.";
	else if (vendor == 2392) vendorText = "CompuLink Research, Inc.";
	else if (vendor == 2393) vendorText = "Cologne Chip Designs GmbH";
	else if (vendor == 2394) vendorText = "Portsmith";
	else if (vendor == 2395) vendorText = "Medialogic Corporation";
	else if (vendor == 2396) vendorText = "K-Tec Electronics";
	else if (vendor == 2397) vendorText = "Polycom, Inc.";
	else if (vendor == 2408) vendorText = "Catalyst Enterprises, Inc.";
	else if (vendor == 2417) vendorText = "GretagMacbeth AG";
	else if (vendor == 2419) vendorText = "Axalto Schlumberger";
	else if (vendor == 2420) vendorText = "Datagraphix, a business unit of Anacomp";
	else if (vendor == 2421) vendorText = "OL'E Communications, Inc.";
	else if (vendor == 2422) vendorText = "Adirondack Wire & Cable";
	else if (vendor == 2423) vendorText = "Lightsurf Technologies";
	else if (vendor == 2424) vendorText = "Beckhoff Gmbh";
	else if (vendor == 2425) vendorText = "Jeilin Technology Corp., Ltd.";
	else if (vendor == 2426) vendorText = "Minds At Work LLC";
	else if (vendor == 2427) vendorText = "Knudsen Engineering Limited";
	else if (vendor == 2428) vendorText = "Marunix Co., Ltd.";
	else if (vendor == 2429) vendorText = "Rosun Technologies, Inc.";
	else if (vendor == 2431) vendorText = "Barun Electronics Co. Ltd.";
	else if (vendor == 2433) vendorText = "Oak Technology Ltd.";
	else if (vendor == 2436) vendorText = "Apricorn";
	else if (vendor == 2438) vendorText = "Matsushita Electric Works, Ltd.";
	else if (vendor == 2444) vendorText = "Vitana Corporation";
	else if (vendor == 2445) vendorText = "INDesign";
	else if (vendor == 2446) vendorText = "Integrated Intellectual Property Inc.";
	else if (vendor == 2447) vendorText = "Kenwood TMI Corporation";
	else if (vendor == 2454) vendorText = "Integrated Telecom Express, Inc.";
	else if (vendor == 2467) vendorText = "PairGain Technologies";
	else if (vendor == 2468) vendorText = "Contech Research, Inc.";
	else if (vendor == 2469) vendorText = "VCON Telecommunications";
	else if (vendor == 2470) vendorText = "Poinchips";
	else if (vendor == 2471) vendorText = "Data Transmission Network Corp.";
	else if (vendor == 2472) vendorText = "Lin Shiung Enterprise Co., Ltd.";
	else if (vendor == 2473) vendorText = "Smart Card Technologies Co., Ltd.";
	else if (vendor == 2474) vendorText = "Intersil Corporation";
	else if (vendor == 2475) vendorText = "Japan Cash Machine Co., Ltd.";
	else if (vendor == 2478) vendorText = "Tripp Lite";
	else if (vendor == 2482) vendorText = "Franklin Electronic Publishers";
	else if (vendor == 2483) vendorText = "Altius Solutions, Inc.";
	else if (vendor == 2484) vendorText = "MDS Telephone Systems";
	else if (vendor == 2485) vendorText = "Celltrix Technology Co., Ltd.";
	else if (vendor == 2497) vendorText = "ARRIS International";
	else if (vendor == 2498) vendorText = "NISCA Corporation";
	else if (vendor == 2499) vendorText = "ACTIVCARD, INC.";
	else if (vendor == 2500) vendorText = "ACTiSYS Corporation";
	else if (vendor == 2501) vendorText = "Memory Corporation";
	else if (vendor == 2508) vendorText = "Workbit Corporation";
	else if (vendor == 2509) vendorText = "Psion Dacom Plc";
	else if (vendor == 2510) vendorText = "City Electronics Ltd.";
	else if (vendor == 2511) vendorText = "Electronics Testing Center, Taiwan";
	else if (vendor == 2513) vendorText = "NeoMagic Inc.";
	else if (vendor == 2514) vendorText = "Vreelin Engineering Inc.";
	else if (vendor == 2515) vendorText = "COM ONE";
	else if (vendor == 2521) vendorText = "Jungo";
	else if (vendor == 2522) vendorText = "A-FOUR TECH CO., LTD.";
	else if (vendor == 2523) vendorText = "Measurement Computing Corporation";
	else if (vendor == 2524) vendorText = "AIMEX Corporation";
	else if (vendor == 2525) vendorText = "Fellowes Manufacturing Co.";
	else if (vendor == 2527) vendorText = "Addonics Technologies Corp.";
	else if (vendor == 2529) vendorText = "Intellon Corporation";
	else if (vendor == 2533) vendorText = "Jo-Dan International, Inc.";
	else if (vendor == 2534) vendorText = "Silutia, Inc.";
	else if (vendor == 2535) vendorText = "Real 3D, Inc.";
	else if (vendor == 2536) vendorText = "AKAI  professional M.I. Corp.";
	else if (vendor == 2537) vendorText = "CHEN-SOURCE INC.";
	else if (vendor == 2549) vendorText = "ARESCOM";
	else if (vendor == 2550) vendorText = "RocketChips, Inc.";
	else if (vendor == 2551) vendorText = "EDU-SCIENCE (H.K.) LIMITED";
	else if (vendor == 2552) vendorText = "SoftConnex Technologies, Inc.";
	else if (vendor == 2553) vendorText = "Bay Associates";
	else if (vendor == 2554) vendorText = "Mtek Vision";
	else if (vendor == 2555) vendorText = "Altera";
	else if (vendor == 2559) vendorText = "Gain Technology Corp.";
	else if (vendor == 2560) vendorText = "Liquid Audio";
	else if (vendor == 2561) vendorText = "ViA, Inc.";
	else if (vendor == 2571) vendorText = "Cybex Computer Products Corporation";
	else if (vendor == 2577) vendorText = "Xentec Incorporated";
	else if (vendor == 2578) vendorText = "Cambridge Silicon Radio Ltd.";
	else if (vendor == 2579) vendorText = "Telebyte Inc.";
	else if (vendor == 2580) vendorText = "Spacelabs Healthcare Medical Inc.";
	else if (vendor == 2581) vendorText = "Scalar Corporation";
	else if (vendor == 2582) vendorText = "Trek Technology (S) Pte Ltd";
	else if (vendor == 2583) vendorText = "HOYA Corporation";
	else if (vendor == 2584) vendorText = "Heidelberger Druckmaschinen AG";
	else if (vendor == 2585) vendorText = "Hua Geng Technologies Inc.";
	else if (vendor == 2593) vendorText = "Medtronic Physio Control Corp.";
	else if (vendor == 2594) vendorText = "Century Semiconductor USA, Inc.";
	else if (vendor == 2595) vendorText = "NDS Technologies Israel Ltd.";
	else if (vendor == 2617) vendorText = "Gilat Satellite Networks Ltd.";
	else if (vendor == 2618) vendorText = "PentaMedia Co., Ltd.";
	else if (vendor == 2620) vendorText = "NTT DoCoMo,Inc.";
	else if (vendor == 2621) vendorText = "Varo Vision";
	else if (vendor == 2627) vendorText = "Boca Systems Inc.";
	else if (vendor == 2628) vendorText = "TurboLinux";
	else if (vendor == 2629) vendorText = "Look&Say co., Ltd.";
	else if (vendor == 2630) vendorText = "Davicom Semiconductor, Inc.";
	else if (vendor == 2631) vendorText = "Hirose Electric Co., Ltd.";
	else if (vendor == 2632) vendorText = "I/O Interconnect";
	else if (vendor == 2635) vendorText = "Fujitsu Media Devices Limited";
	else if (vendor == 2636) vendorText = "COMPUTEX Co., Ltd.";
	else if (vendor == 2637) vendorText = "Evolution Electronics Ltd.";
	else if (vendor == 2638) vendorText = "Steinberg Soft-und Hardware GmbH";
	else if (vendor == 2639) vendorText = "Litton Systems Inc.";
	else if (vendor == 2640) vendorText = "Mimaki Engineering Co., Ltd.";
	else if (vendor == 2641) vendorText = "Sony Electronics Inc.";
	else if (vendor == 2642) vendorText = "JEBSEE ELECTRONICS CO., LTD.";
	else if (vendor == 2643) vendorText = "Portable Peripheral Co., Ltd.";
	else if (vendor == 2650) vendorText = "Electronics For Imaging, Inc.";
	else if (vendor == 2651) vendorText = "EASICS NV";
	else if (vendor == 2652) vendorText = "Broadcom Corp.";
	else if (vendor == 2653) vendorText = "Diatrend Corporation";
	else if (vendor == 2654) vendorText = "Spinnaker Systems Inc.";
	else if (vendor == 2661) vendorText = "FullAudio, Inc.";
	else if (vendor == 2662) vendorText = "ClearCube Technology INT LABS";
	else if (vendor == 2663) vendorText = "Medeli Electronics Co, Ltd.";
	else if (vendor == 2664) vendorText = "COMAIDE Corporation";
	else if (vendor == 2665) vendorText = "Chroma ate Inc.";
	else if (vendor == 2666) vendorText = "Newcom Inc.";
	else if (vendor == 2667) vendorText = "Green House Co., Ltd.";
	else if (vendor == 2668) vendorText = "Integrated Circuit Systems Inc.";
	else if (vendor == 2669) vendorText = "UPS Manufacturing";
	else if (vendor == 2670) vendorText = "Benwin";
	else if (vendor == 2671) vendorText = "Core Technology, Inc.";
	else if (vendor == 2672) vendorText = "International Game Technology";
	else if (vendor == 2673) vendorText = "VIPColor Technologies USA, Inc.";
	else if (vendor == 2674) vendorText = "Sanwa Denshi";
	else if (vendor == 2685) vendorText = "Intertek NSTL";
	else if (vendor == 2686) vendorText = "Octagon Systems Corporation";
	else if (vendor == 2687) vendorText = "AVerMedia MicroSystems";
	else if (vendor == 2688) vendorText = "Rexon Technology Corp., Ltd";
	else if (vendor == 2689) vendorText = "CHESEN ELECTRONICS CORP.";
	else if (vendor == 2690) vendorText = "SYSCAN";
	else if (vendor == 2691) vendorText = "NextComm, Inc.";
	else if (vendor == 2692) vendorText = "Maui Innovative Peripherals";
	else if (vendor == 2693) vendorText = "IDEXX LABS";
	else if (vendor == 2694) vendorText = "NITGen Co., Ltd.";
	else if (vendor == 2700) vendorText = "Tecmar";
	else if (vendor == 2701) vendorText = "Picturetel";
	else if (vendor == 2702) vendorText = "Japan Aviation Electronics Industry Ltd. (JAE)";
	else if (vendor == 2703) vendorText = "Young Chang Co. Ltd.";
	else if (vendor == 2704) vendorText = "Candy Technology Co., Ltd.";
	else if (vendor == 2705) vendorText = "Globlink Technology Inc.";
	else if (vendor == 2706) vendorText = "EGO SYStems Inc.";
	else if (vendor == 2707) vendorText = "C Technologies AB (publ)";
	else if (vendor == 2708) vendorText = "Intersense";
	else if (vendor == 2723) vendorText = "Lava Computer Mfg. Inc.";
	else if (vendor == 2724) vendorText = "Develco Elektronik";
	else if (vendor == 2725) vendorText = "First International Digital";
	else if (vendor == 2726) vendorText = "Perception Digital Limited";
	else if (vendor == 2727) vendorText = "Wincor Nixdorf GmbH & Co KG";
	else if (vendor == 2728) vendorText = "TriGem Computer, Inc.";
	else if (vendor == 2729) vendorText = "Baromtec Co.";
	else if (vendor == 2730) vendorText = "Japan CBM Corporation";
	else if (vendor == 2731) vendorText = "Vision Shape Europe SA.";
	else if (vendor == 2732) vendorText = "iCompression Inc.";
	else if (vendor == 2733) vendorText = "Rohde & Schwarz GmbH & Co. KG";
	else if (vendor == 2734) vendorText = "NEC infrontia Nitsuko Corporation";
	else if (vendor == 2735) vendorText = "digitalway co., ltd.";
	else if (vendor == 2736) vendorText = "Arrow Strong Electronics CO. LTD";
	else if (vendor == 2755) vendorText = "SANYO ON Semiconductor Company Micro (System Solutions Co., Ltd)";
	else if (vendor == 2756) vendorText = "LECO CORPORATION";
	else if (vendor == 2757) vendorText = "I & C Corporation";
	else if (vendor == 2758) vendorText = "Singing Electrons, Inc.";
	else if (vendor == 2759) vendorText = "Panwest Corporation";
	else if (vendor == 2760) vendorText = "Vimicro Z-Star Microelectronics Corporation";
	else if (vendor == 2761) vendorText = "Micro Solutions, Inc.";
	else if (vendor == 2764) vendorText = "Koga Electronics Co.";
	else if (vendor == 2765) vendorText = "ID Tech";
	else if (vendor == 2766) vendorText = "ZyDAS Technology Corporation";
	else if (vendor == 2767) vendorText = "Intoto, Inc.";
	else if (vendor == 2768) vendorText = "Intellix Corp.";
	else if (vendor == 2769) vendorText = "Remotec Technology Ltd.";
	else if (vendor == 2770) vendorText = "Service & Quality Technology Co., Ltd.";
	else if (vendor == 2787) vendorText = "Allion Test Labs, Inc.";
	else if (vendor == 2788) vendorText = "Taito Corporation";
	else if (vendor == 2789) vendorText = "MacroSystem Digital Video AG";
	else if (vendor == 2790) vendorText = "EVI, Inc.";
	else if (vendor == 2791) vendorText = "Neodym Systems Inc.";
	else if (vendor == 2792) vendorText = "System Support Co., Ltd.";
	else if (vendor == 2793) vendorText = "North Shore Circuit Design L.L.P.";
	else if (vendor == 2794) vendorText = "SciEssence, LLC";
	else if (vendor == 2795) vendorText = "TTP Communications Ltd.";
	else if (vendor == 2796) vendorText = "Neodio Technologies Corporation";
	else if (vendor == 2800) vendorText = "Option NV";
	else if (vendor == 2806) vendorText = "SILVER I CO., LTD.";
	else if (vendor == 2807) vendorText = "B2C2, Inc.";
	else if (vendor == 2812) vendorText = "Zaptronix Ltd";
	else if (vendor == 2813) vendorText = "Tateno Dennou, Inc.";
	else if (vendor == 2814) vendorText = "Cummins Engine Company";
	else if (vendor == 2815) vendorText = "Jump Zone Network Products, Inc.";
	else if (vendor == 2816) vendorText = "INGENICO";
	else if (vendor == 2821) vendorText = "ASUSTek Computer Inc.";
	else if (vendor == 2828) vendorText = "Todos Data System AB";
	else if (vendor == 2830) vendorText = "GN Netcom";
	else if (vendor == 2831) vendorText = "AVID Technology";
	else if (vendor == 2832) vendorText = "Pcally";
	else if (vendor == 2833) vendorText = "I Tech Solutions Co., Ltd.";
	else if (vendor == 2846) vendorText = "Electronic Warfare Assoc., Inc. (EWA)";
	else if (vendor == 2847) vendorText = "Insyde Software";
	else if (vendor == 2848) vendorText = "TransDimension Inc.";
	else if (vendor == 2849) vendorText = "Yokogawa Electric Corporation";
	else if (vendor == 2850) vendorText = "Japan System Development Co. Ltd.";
	else if (vendor == 2851) vendorText = "Pan-Asia Electronics Co., Ltd.";
	else if (vendor == 2852) vendorText = "Link Evolution Corp.";
	else if (vendor == 2855) vendorText = "Ritek Corporation";
	else if (vendor == 2856) vendorText = "Kenwood Corporation";
	else if (vendor == 2860) vendorText = "Village Center, Inc.";
	else if (vendor == 2864) vendorText = "NewHeights Software";
	else if (vendor == 2867) vendorText = "Contour Design, Inc.";
	else if (vendor == 2871) vendorText = "Hitachi ULSI Systems Co., Ltd.";
	else if (vendor == 2873) vendorText = "Omnidirectional Control Technology Inc.";
	else if (vendor == 2874) vendorText = "IPaxess";
	else if (vendor == 2875) vendorText = "Bromax Communications, Inc.";
	else if (vendor == 2876) vendorText = "Olivetti Tecnost S.p.A";
	else if (vendor == 2878) vendorText = "Kikusui Electronics Corporation";
	else if (vendor == 2881) vendorText = "Hal Corporation";
	else if (vendor == 2888) vendorText = "TechnoTrend AG";
	else if (vendor == 2889) vendorText = "ASCII Corporation";
	else if (vendor == 2894) vendorText = "Musical Electronics Ltd.";
	else if (vendor == 2898) vendorText = "Colorado MicroDisplay, Inc";
	else if (vendor == 2900) vendorText = "Sinbon Electronics Co., Ltd.";
	else if (vendor == 2905) vendorText = "Lake Communications Ltd.";
	else if (vendor == 2912) vendorText = "Nsine Limited";
	else if (vendor == 2913) vendorText = "NEC Viewtechnology, Ltd.";
	else if (vendor == 2914) vendorText = "Orange Micro, Inc.";
	else if (vendor == 2917) vendorText = "Expert Magnetics Corp.";
	else if (vendor == 2921) vendorText = "CacheVision";
	else if (vendor == 2922) vendorText = "Maxim Integrated Products";
	else if (vendor == 2927) vendorText = "Nagano Japan Radio Co., Ltd";
	else if (vendor == 2928) vendorText = "PortalPlayer, Inc";
	else if (vendor == 2933) vendorText = "Roland DG Corporation";
	else if (vendor == 2949) vendorText = "Elkat Electronics (M) SDN. BHD.";
	else if (vendor == 2950) vendorText = "Exputer Systems, Inc.";
	else if (vendor == 2965) vendorText = "ASIX Electronics Corporation";
	else if (vendor == 2966) vendorText = "SEWON TELECOM";
	else if (vendor == 2967) vendorText = "O2 Micro, Inc.";
	else if (vendor == 2991) vendorText = "U.S. Robotics";
	else if (vendor == 2992) vendorText = "Concord Camera Corp.";
	else if (vendor == 2994) vendorText = "Ambit Microsystems Corporation";
	else if (vendor == 2995) vendorText = "Ofuji Technology";
	else if (vendor == 2996) vendorText = "HTC Corporation";
	else if (vendor == 2997) vendorText = "Murata Manufacturing Co., Ltd.";
	else if (vendor == 3000) vendorText = "Hitachi Renesas Semiconductor and Devices Sales Co., Ltd.";
	else if (vendor == 3009) vendorText = "FUW YNG ELECTRONICS COMPANY LTD";
	else if (vendor == 3010) vendorText = "Seagate Technology LLC";
	else if (vendor == 3011) vendorText = "IPWireless, Inc.";
	else if (vendor == 3014) vendorText = "ExWAY Inc.";
	else if (vendor == 3015) vendorText = "X10 Wireless Technology, Inc.";
	else if (vendor == 3019) vendorText = "Perfect Technic Enterprise Co. LTD";
	else if (vendor == 3034) vendorText = "Realtek Semiconductor Corp.";
	else if (vendor == 3035) vendorText = "Ericsson AB";
	else if (vendor == 3042) vendorText = "Kanda Tsushin Kogyo Co., LTD";
	else if (vendor == 3044) vendorText = "Elka International Ltd.";
	else if (vendor == 3045) vendorText = "DOME Imaging Systems, Inc";
	else if (vendor == 3046) vendorText = "Wonderful Photoelectricity (DongGuan), Co., Ltd.";
	else if (vendor == 3054) vendorText = "LTK International Limited";
	else if (vendor == 3056) vendorText = "Pace Micro Technology PLC";
	else if (vendor == 3062) vendorText = "Addonics Technologies, Inc.";
	else if (vendor == 3063) vendorText = "Sunny Giken Inc.";
	else if (vendor == 3064) vendorText = "Fujitsu Siemens Computers GmbH";
	else if (vendor == 3078) vendorText = "Hasbro, Inc.";
	else if (vendor == 3079) vendorText = "Infinite Data Storage LTD";
	else if (vendor == 3083) vendorText = "Dura Micro, Inc.";
	else if (vendor == 3093) vendorText = "Iris Graphics";
	else if (vendor == 3100) vendorText = "Hang Zhou Silan Microelectronics Co. Ltd";
	else if (vendor == 3106) vendorText = "TallyGenicom L.P.";
	else if (vendor == 3108) vendorText = "Taiyo Yuden Co., Ltd.";
	else if (vendor == 3109) vendorText = "Sampo Corporation";
	else if (vendor == 3128) vendorText = "Der An Electric Wire & Cable Co. Ltd.";
	else if (vendor == 3129) vendorText = "Aeroflex";
	else if (vendor == 3130) vendorText = "Furui Precise Component (Kunshan) Co., Ltd";
	else if (vendor == 3131) vendorText = "Komatsu Ltd.";
	else if (vendor == 3132) vendorText = "Radius Co., Ltd.";
	else if (vendor == 3140) vendorText = "Motorola iDEN";
	else if (vendor == 3141) vendorText = "Sonix Technology Co., Ltd.";
	else if (vendor == 3154) vendorText = "Sealevel Systems, Inc.";
	else if (vendor == 3156) vendorText = "GLORY LTD.";
	else if (vendor == 3157) vendorText = "Spectrum Digital Inc.";
	else if (vendor == 3158) vendorText = "Billion Bright (HK) Corporation Limited";
	else if (vendor == 3159) vendorText = "Imaginative Design Operation Co. Ltd.";
	else if (vendor == 3161) vendorText = "Dong Guan Shinko Wire Co., Ltd.";
	else if (vendor == 3168) vendorText = "Apogee Electronics Corp";
	else if (vendor == 3170) vendorText = "Chant Sincere Co., Ltd";
	else if (vendor == 3171) vendorText = "Toko, Inc.";
	else if (vendor == 3172) vendorText = "Signality System Engineering Co., Ltd.";
	else if (vendor == 3173) vendorText = "Eminence Enterprise Co., Ltd.";
	else if (vendor == 3175) vendorText = "Concept Telecom Ltd";
	else if (vendor == 3176) vendorText = "Whanam Electronics Co., Ltd.";
	else if (vendor == 3190) vendorText = "Solid State System Co., Ltd.";
	else if (vendor == 3193) vendorText = "NuConnex Technologies PTE LTD";
	else if (vendor == 3194) vendorText = "Wing-Span Enterprise Co., Ltd.";
	else if (vendor == 3208) vendorText = "Kyocera Wireless Corp.";
	else if (vendor == 3209) vendorText = "Honda Tsushin Kogyo Co., Ltd";
	else if (vendor == 3213) vendorText = "Tempo";
	else if (vendor == 3214) vendorText = "Cesscom Co., Ltd.";
	else if (vendor == 3225) vendorText = "Innochips Co., Ltd.";
	else if (vendor == 3226) vendorText = "Hanwool Robotics Corp.";
	else if (vendor == 3238) vendorText = "Castles Technology Co. Ltd.";
	else if (vendor == 3245) vendorText = "Motorola CGISS G&PS";
	else if (vendor == 3247) vendorText = "Buslink";
	else if (vendor == 3255) vendorText = "Singatron Enterprise Co. Ltd.";
	else if (vendor == 3256) vendorText = "Opticis Co., Ltd.";
	else if (vendor == 3259) vendorText = "Shanghai Darong Electronics Co., Ltd.";
	else if (vendor == 3261) vendorText = "Pentel Co., Ltd. (Electronics Equipment Div.)";
	else if (vendor == 3262) vendorText = "Keryx Technologies, Inc.";
	else if (vendor == 3263) vendorText = "Union Genius Computer Co., Ltd";
	else if (vendor == 3264) vendorText = "Kuon Yi Industrial Corp.";
	else if (vendor == 3266) vendorText = "Timex Corporation";
	else if (vendor == 3268) vendorText = "emsys Embedded Systems GmbH";
	else if (vendor == 3270) vendorText = "INTERMAGIC CORP.";
	else if (vendor == 3274) vendorText = "AMPHENOL";
	else if (vendor == 3276) vendorText = "DOMEX TECHNOLOGY CORPORATION";
	else if (vendor == 3289) vendorText = "Shin Din Cable Ltd.";
	else if (vendor == 3294) vendorText = "Z-Com INC.";
	else if (vendor == 3313) vendorText = "e-CONN ELECTRONIC CO., LTD.";
	else if (vendor == 3314) vendorText = "ENE Technology Inc.";
	else if (vendor == 3315) vendorText = "Atheros Communications, Inc.";
	else if (vendor == 3318) vendorText = "Compucable Corporation";
	else if (vendor == 3321) vendorText = "Central System Research Co., Ltd.";
	else if (vendor == 3324) vendorText = "Minolta-QMS, Inc.";
	else if (vendor == 3340) vendorText = "Astron Electronics Co., Ltd.";
	else if (vendor == 3343) vendorText = "Feng Shin Cable Co. Ltd.";
	else if (vendor == 3347) vendorText = "BMF CORPORATION";
	else if (vendor == 3348) vendorText = "Array Comm, Inc.";
	else if (vendor == 3349) vendorText = "OnStream b.v.";
	else if (vendor == 3350) vendorText = "Hi-Touch Imaging Technologies Co., Ltd.";
	else if (vendor == 3351) vendorText = "NALTEC, Inc.";
	else if (vendor == 3353) vendorText = "Hank Connection Industrial Co., Ltd.";
	else if (vendor == 3381) vendorText = "Dah Kun Co., Ltd.";
	else if (vendor == 3388) vendorText = "SRI CABLE TECHNOLOGY LTD.";
	else if (vendor == 3389) vendorText = "TANGTOP TECHNOLOGY CO., LTD.";
	else if (vendor == 3391) vendorText = "MTS Systems Corporation";
	else if (vendor == 3393) vendorText = "Ta Yun Electronic Technology Co., Ltd.";
	else if (vendor == 3394) vendorText = "FULL DER CO., LTD.";
	else if (vendor == 3401) vendorText = "Maxtor";
	else if (vendor == 3402) vendorText = "NF Corporation";
	else if (vendor == 3403) vendorText = "Grape Systems Inc.";
	else if (vendor == 3405) vendorText = "Coherent Inc.";
	else if (vendor == 3406) vendorText = "Agere Systems Netherland BV";
	else if (vendor == 3409) vendorText = "Volex (Asia) Pte Ltd";
	else if (vendor == 3411) vendorText = "HMI Co., Ltd.";
	else if (vendor == 3413) vendorText = "ASKA Technologies Inc.";
	else if (vendor == 3414) vendorText = "AVLAB Technology, Inc.";
	else if (vendor == 3423) vendorText = "CSI, Inc.";
	else if (vendor == 3424) vendorText = "IVL Technologies Ltd.";
	else if (vendor == 3425) vendorText = "MEILU ELECTRONICS (SHENZHEN) CO., LTD.";
	else if (vendor == 3426) vendorText = "Darfon Electronics Corp.";
	else if (vendor == 3427) vendorText = "Fritz Gegauf AG";
	else if (vendor == 3428) vendorText = "DXG Technology Corp.";
	else if (vendor == 3429) vendorText = "KMJP CO., LTD.";
	else if (vendor == 3430) vendorText = "TMT";
	else if (vendor == 3431) vendorText = "Advanet Inc.";
	else if (vendor == 3432) vendorText = "Super Link Electronics Co., Ltd.";
	else if (vendor == 3433) vendorText = "NSI";
	else if (vendor == 3434) vendorText = "Megapower International Corp.";
	else if (vendor == 3435) vendorText = "And-Or Logic";
	else if (vendor == 3440) vendorText = "Try Computer Co. LTD.";
	else if (vendor == 3441) vendorText = "Hirakawa Hewtech Corp.";
	else if (vendor == 3442) vendorText = "Winmate Communication Inc.";
	else if (vendor == 3443) vendorText = "Hit's Communications INC.";
	else if (vendor == 3446) vendorText = "MFP Korea, Inc.";
	else if (vendor == 3447) vendorText = "Power Sentry/Newpoint";
	else if (vendor == 3448) vendorText = "Japan Distributor Corporation";
	else if (vendor == 3450) vendorText = "MARX CryptoTech LP";
	else if (vendor == 3452) vendorText = "Taiwan Line Tek Electronic Co., Ltd.";
	else if (vendor == 3453) vendorText = "Add-On Technology Co., Ltd.";
	else if (vendor == 3454) vendorText = "American Computer & Digital Components";
	else if (vendor == 3455) vendorText = "Essential Reality LLC";
	else if (vendor == 3456) vendorText = "H.R. Silvine Electronics Inc.";
	else if (vendor == 3457) vendorText = "TechnoVision";
	else if (vendor == 3459) vendorText = "Think Outside, Inc.";
	else if (vendor == 3463) vendorText = "Dolby Laboratories Inc.";
	else if (vendor == 3465) vendorText = "Oz Software";
	else if (vendor == 3466) vendorText = "KING JIM CO., LTD.";
	else if (vendor == 3467) vendorText = "Ascom Telecommunications Ltd.";
	else if (vendor == 3468) vendorText = "C-MEDIA ELECTRONICS INC.";
	else if (vendor == 3469) vendorText = "Promotion & Display Technology Ltd.";
	else if (vendor == 3470) vendorText = "Global Sun Technology Inc.";
	else if (vendor == 3471) vendorText = "Pitney Bowes";
	else if (vendor == 3472) vendorText = "Sure-Fire Electrical Corporation";
	else if (vendor == 3480) vendorText = "Mars Semiconductor Corp.";
	else if (vendor == 3481) vendorText = "Trazer Technologies Inc.";
	else if (vendor == 3482) vendorText = "RTX Telecom A/S";
	else if (vendor == 3483) vendorText = "Tat Shing Electrical Co.";
	else if (vendor == 3484) vendorText = "Chee Chen Hi-Technology Co., Ltd.";
	else if (vendor == 3485) vendorText = "Sanwa Supply Inc";
	else if (vendor == 3486) vendorText = "Avaya";
	else if (vendor == 3487) vendorText = "Powercom Co., Ltd.";
	else if (vendor == 3488) vendorText = "Danger Research";
	else if (vendor == 3489) vendorText = "Suzhou Peter's Precise Industrial Co., Ltd.";
	else if (vendor == 3491) vendorText = "Nippon Electro-Sensory Devices Corporation";
	else if (vendor == 3495) vendorText = "IOGEAR, Inc.";
	else if (vendor == 3501) vendorText = "Westover Scientific";
	else if (vendor == 3504) vendorText = "Micro-Star International Co., Ltd.";
	else if (vendor == 3505) vendorText = "Wen Te Electronics Co., Ltd.";
	else if (vendor == 3506) vendorText = "Shian Hwi Plug Parts, Plastic Factory";
	else if (vendor == 3507) vendorText = "Tekram Technology Co. Ltd.";
	else if (vendor == 3508) vendorText = "Chung Fu Chen Yeh Enterprise Corporation";
	else if (vendor == 3518) vendorText = "Jiuh Shiuh Precision Industry Co., Ltd.";
	else if (vendor == 3519) vendorText = "Quik Tech Solutions";
	else if (vendor == 3520) vendorText = "Great Notions";
	else if (vendor == 3521) vendorText = "Tamagawa Seiki Co., Ltd.";
	else if (vendor == 3523) vendorText = "Athena Smartcard Solutions Inc.";
	else if (vendor == 3524) vendorText = "Macpower Peripherals Ltd.";
	else if (vendor == 3525) vendorText = "SDK Co, Ltd.";
	else if (vendor == 3526) vendorText = "Precision Squared Technology Corporation";
	else if (vendor == 3527) vendorText = "First Cable Line, Inc.";
	else if (vendor == 3537) vendorText = "Contek Electronics Co., Ltd.";
	else if (vendor == 3538) vendorText = "Power Quotient International Co., Ltd.";
	else if (vendor == 3539) vendorText = "MediaQ";
	else if (vendor == 3540) vendorText = "Custom Engineering SPA";
	else if (vendor == 3541) vendorText = "California Micro Devices";
	else if (vendor == 3543) vendorText = "KOCOM CO., LTD";
	else if (vendor == 3545) vendorText = "HighSpeed Surfing";
	else if (vendor == 3546) vendorText = "Integrated Circuit Solution Inc.";
	else if (vendor == 3547) vendorText = "Tamarack Inc.";
	else if (vendor == 3548) vendorText = "Takaotec";
	else if (vendor == 3549) vendorText = "Datelink Technology Co., Ltd.";
	else if (vendor == 3550) vendorText = "UBICOM, INC";
	else if (vendor == 3552) vendorText = "BD Consumer Healthcare";
	else if (vendor == 3562) vendorText = "UTECH Electronic (D.G.) Co., Ltd.";
	else if (vendor == 3563) vendorText = "Lean Horn Co.";
	else if (vendor == 3564) vendorText = "Callserve Communications Ltd.";
	else if (vendor == 3565) vendorText = "Novasonics";
	else if (vendor == 3566) vendorText = "Lifetime Memory Products";
	else if (vendor == 3567) vendorText = "Full Rise Electronic Co., Ltd.";
	else if (vendor == 3574) vendorText = "Sitecom Europe B.V.";
	else if (vendor == 3575) vendorText = "Mobile Action Technology Inc.";
	else if (vendor == 3576) vendorText = "Hoya Computer Co., Ltd.";
	else if (vendor == 3577) vendorText = "Nice Fountain Industrial Co., Ltd.";
	else if (vendor == 3578) vendorText = "Toyo Communication Equipment Co., Ltd.";
	else if (vendor == 3580) vendorText = "General Touch Technology Co., Ltd.";
	else if (vendor == 3585) vendorText = "Sheng Xiang Investment Ltd.";
	else if (vendor == 3586) vendorText = "Doowon Co., LTD";
	else if (vendor == 3587) vendorText = "Nippon Systemware Co., Ltd.";
	else if (vendor == 3591) vendorText = "Viewtek Co., Ltd";
	else if (vendor == 3592) vendorText = "Winbest Technology Co., Ltd.";
	else if (vendor == 3593) vendorText = "Winskon Cabling Specialist Co., Ltd.";
	else if (vendor == 3599) vendorText = "VMWare, Inc.";
	else if (vendor == 3602) vendorText = "Danam Communications Inc.";
	else if (vendor == 3603) vendorText = "Lugh Networks, Inc.";
	else if (vendor == 3605) vendorText = "Tellert Elektronik GmbH";
	else if (vendor == 3606) vendorText = "JMTEK, LLC";
	else if (vendor == 3607) vendorText = "Walex Electronic Ltd.";
	else if (vendor == 3608) vendorText = "UNIWIDE Technologies";
	else if (vendor == 3615) vendorText = "Cabin Industrial Co., Ltd.";
	else if (vendor == 3618) vendorText = "Symbian Ltd.";
	else if (vendor == 3619) vendorText = "Liou Yuane International Ltd.";
	else if (vendor == 3620) vendorText = "Samson Electric Wire Co., Ltd.";
	else if (vendor == 3621) vendorText = "VinChip Systems, Inc.";
	else if (vendor == 3622) vendorText = "J-Phone East Co., Ltd.";
	else if (vendor == 3632) vendorText = "HeartMath LLC";
	else if (vendor == 3636) vendorText = "Micro Computer Control Corp.";
	else if (vendor == 3637) vendorText = "3Pea Technologies, Inc.";
	else if (vendor == 3638) vendorText = "TiePie engineering";
	else if (vendor == 3639) vendorText = "Alpha Data Corp.";
	else if (vendor == 3640) vendorText = "Stratitec, Inc.";
	else if (vendor == 3641) vendorText = "Smart Modular Technologies, Inc.";
	else if (vendor == 3642) vendorText = "Neostar Technology Co., Ltd.";
	else if (vendor == 3643) vendorText = "Mansella Ltd.";
	else if (vendor == 3644) vendorText = "Raytec Electronic Co., Ltd.";
	else if (vendor == 3650) vendorText = "Puretek Industrial Co., Ltd.";
	else if (vendor == 3651) vendorText = "Holly Lin International Technology Inc.";
	else if (vendor == 3652) vendorText = "Sun-Riseful Technology Co., Ltd.";
	else if (vendor == 3653) vendorText = "SafeNet B.V.";
	else if (vendor == 3654) vendorText = "Delphi Automotive";
	else if (vendor == 3658) vendorText = "Shenzhen Bao Hing Electric Wire & Cable Mfr. Co.";
	else if (vendor == 3659) vendorText = "System General Corp.";
	else if (vendor == 3660) vendorText = "Radica Games Ltd.";
	else if (vendor == 3661) vendorText = "Hong Shi Precision Corp.";
	else if (vendor == 3662) vendorText = "Lih Duo Intl. Co., Ltd.";
	else if (vendor == 3669) vendorText = "Speed Dragon Multimedia Ltd.";
	else if (vendor == 3674) vendorText = "ACTIVE CO., LTD.";
	else if (vendor == 3675) vendorText = "Union Power Information Industrial Co., Ltd.";
	else if (vendor == 3676) vendorText = "Bitland Information Technology Co., Ltd.";
	else if (vendor == 3677) vendorText = "Neltron Industrial Co., Ltd.";
	else if (vendor == 3678) vendorText = "Conwise Technology Co., Ltd.";
	else if (vendor == 3679) vendorText = "Entone Technologies";
	else if (vendor == 3680) vendorText = "XAVi Technologies Corp.";
	else if (vendor == 3681) vendorText = "E-Pen InMotion Inc.";
	else if (vendor == 3687) vendorText = "Fossil";
	else if (vendor == 3689) vendorText = "A Global Partner Corporation";
	else if (vendor == 3690) vendorText = "Megawin Technology Co., Ltd.";
	else if (vendor == 3696) vendorText = "Tokyo Electronic Industry Co, LTD.";
	else if (vendor == 3697) vendorText = "Schwarzer GmbH";
	else if (vendor == 3698) vendorText = "Hsi-Chin Electronics Co., Ltd.";
	else if (vendor == 3699) vendorText = "MCK Communications, Inc.";
	else if (vendor == 3700) vendorText = "Accu-Automation Corp.";
	else if (vendor == 3701) vendorText = "TVS Electronics Limited";
	else if (vendor == 3704) vendorText = "Ascom Powerline Communications Ltd.";
	else if (vendor == 3707) vendorText = "On-Tech Industry Co., Ltd.";
	else if (vendor == 3708) vendorText = "Legend Holdings Limited";
	else if (vendor == 3714) vendorText = "Ching Tai Electric Wire & Cable Co., Ltd.";
	else if (vendor == 3715) vendorText = "Shin An Wire & Cable Co.";
	else if (vendor == 3716) vendorText = "Elelux International Ltd.";
	else if (vendor == 3721) vendorText = "PRT Manufacturing Ltd.";
	else if (vendor == 3722) vendorText = "FinePoint Innovations, Inc.";
	else if (vendor == 3723) vendorText = "KAO SHIN PRECISION INDUSTRY CO., LTD.";
	else if (vendor == 3724) vendorText = "Well Force Electronic Co., Ltd";
	else if (vendor == 3725) vendorText = "MediaTek Inc.";
	else if (vendor == 3728) vendorText = "CRU WiebeTech LLC";
	else if (vendor == 3729) vendorText = "VTech Engineering Canada Ltd.";
	else if (vendor == 3730) vendorText = "C'S GLORY ENTERPRISE CO., LTD.";
	else if (vendor == 3731) vendorText = "eM Technics Co., Ltd.";
	else if (vendor == 3733) vendorText = "Future Technology Co., Ltd";
	else if (vendor == 3734) vendorText = "APLUX  Communications Ltd.";
	else if (vendor == 3735) vendorText = "Fingerworks, Inc.";
	else if (vendor == 3736) vendorText = "Advanced Analogic Technologies, Inc.";
	else if (vendor == 3737) vendorText = "Parallel Dice Co., Ltd.";
	else if (vendor == 3738) vendorText = "TA HSING INDUSTRIES LTD.";
	else if (vendor == 3739) vendorText = "ADTEC CORPORATION";
	else if (vendor == 3743) vendorText = "TAMURA CORPORATION";
	else if (vendor == 3744) vendorText = "Ours Technology Inc.";
	else if (vendor == 3750) vendorText = "Nihon Computer Co., Ltd.";
	else if (vendor == 3751) vendorText = "MSL Enterprises Corp.";
	else if (vendor == 3752) vendorText = "CenDyne, Inc.";
	else if (vendor == 3757) vendorText = "HUMAX Co., Ltd.";
	else if (vendor == 3761) vendorText = "WIS Technologies, Inc.";
	else if (vendor == 3762) vendorText = "Y-S ELECTRONIC CO., LTD.";
	else if (vendor == 3763) vendorText = "Saint Technology Corp.";
	else if (vendor == 3767) vendorText = "Endor AG";
	else if (vendor == 3768) vendorText = "Mettler-Toledo (Albstadt) GmbH";
	else if (vendor == 3774) vendorText = "VWEB Corporation";
	else if (vendor == 3775) vendorText = "Omega Technology of Taiwan Inc.";
	else if (vendor == 3776) vendorText = "LHI Technology (China) Co., Ltd.";
	else if (vendor == 3777) vendorText = "ABIT Computer Corporation";
	else if (vendor == 3778) vendorText = "Sweetray Industrial Ltd.";
	else if (vendor == 3779) vendorText = "Axell Corporation";
	else if (vendor == 3780) vendorText = "Ballracing Developments Ltd.";
	else if (vendor == 3781) vendorText = "GT Information System Co., Ltd.";
	else if (vendor == 3782) vendorText = "InnoVISION Multimedia Limited";
	else if (vendor == 3783) vendorText = "Theta Link Corporation";
	else if (vendor == 3789) vendorText = "Lite-On IT Corp.";
	else if (vendor == 3790) vendorText = "TaiSol Electronics Co., Ltd.";
	else if (vendor == 3791) vendorText = "Phogenix Imaging, LLC";
	else if (vendor == 3794) vendorText = "Kyoto Micro Computer Co., LTD.";
	else if (vendor == 3795) vendorText = "Wing-Tech Enterprise Co., Ltd.";
	else if (vendor == 3801) vendorText = "Holy Stone Enterprise Co., Ltd.";
	else if (vendor == 3802) vendorText = "ISE NORITAKE ITRON CORPORATION";
	else if (vendor == 3807) vendorText = "e-MDT Co., Ltd.";
	else if (vendor == 3808) vendorText = "SHIMA SEIKI MFG., LTD.";
	else if (vendor == 3809) vendorText = "Sarotech Co., Ltd.";
	else if (vendor == 3810) vendorText = "AMI Semiconductor Inc.";
	else if (vendor == 3811) vendorText = "ComTrue Technology Corporation (Taiwan)";
	else if (vendor == 3812) vendorText = "Sunrich Technology (H.K.) Ltd.";
	else if (vendor == 3822) vendorText = "Digital STREAM Technology, Inc.";
	else if (vendor == 3823) vendorText = "D-WAV SCIENTIFIC CO., LTD.";
	else if (vendor == 3824) vendorText = "Hitachi Cable, Ltd.";
	else if (vendor == 3825) vendorText = "Aichi Micro Intelligent Corporation";
	else if (vendor == 3826) vendorText = "I/OMAGIC CORPORATION";
	else if (vendor == 3827) vendorText = "Lynn Products, Inc.";
	else if (vendor == 3828) vendorText = "DSI Datotech";
	else if (vendor == 3829) vendorText = "PointChips";
	else if (vendor == 3830) vendorText = "Yield Microelectronics Corp.";
	else if (vendor == 3831) vendorText = "SM Tech Co., Ltd.";
	else if (vendor == 3837) vendorText = "Oasis Semiconductor";
	else if (vendor == 3838) vendorText = "WEM TECHNOLOGY INC.";
	else if (vendor == 3846) vendorText = "Visual Frontier Precision Corp.";
	else if (vendor == 3848) vendorText = "CSL Wire & Plug (Shen Zhen) Company";
	else if (vendor == 3852) vendorText = "CAS Corporation";
	else if (vendor == 3853) vendorText = "HORI CO., LTD.";
	else if (vendor == 3854) vendorText = "Energy Full Corp.";
	else if (vendor == 3858) vendorText = "MARS ENGINEERING CORPORATION";
	else if (vendor == 3859) vendorText = "Acetek Technology Co., Ltd.";
	else if (vendor == 3865) vendorText = "ORACOM CO., Ltd.";
	else if (vendor == 3867) vendorText = "Onset Computer Corporation";
	else if (vendor == 3868) vendorText = "Funai Electric Co., Ltd.";
	else if (vendor == 3869) vendorText = "Iwill Corporation";
	else if (vendor == 3872) vendorText = "GENNUM CORPORATION";
	else if (vendor == 3873) vendorText = "IOI Technology Corporation";
	else if (vendor == 3874) vendorText = "SENIOR INDUSTRIES, INC.";
	else if (vendor == 3875) vendorText = "Leader Tech Manufacturer Co., Ltd";
	else if (vendor == 3876) vendorText = "FLEX-P INDUSTRIES SDN.BHD.";
	else if (vendor == 3885) vendorText = "ViPower, Inc.";
	else if (vendor == 3886) vendorText = "Geniality Maple Good Man Corporation";
	else if (vendor == 3887) vendorText = "Priva Design Services";
	else if (vendor == 3888) vendorText = "Jess Technology Co., Ltd.";
	else if (vendor == 3889) vendorText = "Chrysalis Development";
	else if (vendor == 3890) vendorText = "YFC-BonEagle Electric Co., Ltd.";
	else if (vendor == 3891) vendorText = "Futek Electronics, Co., Ltd.";
	else if (vendor == 3895) vendorText = "Kokuyo Co., Ltd.";
	else if (vendor == 3896) vendorText = "Nien-Yi Industrial Corp.";
	else if (vendor == 3905) vendorText = "RDC Semiconductor Co., Ltd.";
	else if (vendor == 3906) vendorText = "Nital Consulting Services, Inc.";
	else if (vendor == 3915) vendorText = "St. John Technology Co., Ltd.";
	else if (vendor == 3916) vendorText = "WORLDWIDE CABLE OPTO CORP.";
	else if (vendor == 3917) vendorText = "Microtune, Inc.";
	else if (vendor == 3918) vendorText = "Freedom Scientific";
	else if (vendor == 3922) vendorText = "WING KEI ELECTRICAL CO., LTD.";
	else if (vendor == 3923) vendorText = "Taiyo Dongguan White Horse Cable Factory Ltd.";
	else if (vendor == 3924) vendorText = "Kawai Musical Instruments Mfg. Co., Ltd.";
	else if (vendor == 3925) vendorText = "AmbiCom, Inc.";
	else if (vendor == 3932) vendorText = "PRAIRIECOMM, INC.";
	else if (vendor == 3933) vendorText = "NewAge International, LLC";
	else if (vendor == 3935) vendorText = "Key Technology Corporation";
	else if (vendor == 3936) vendorText = "GuangZhou Chief Tech Electronic Technology Co. Ltd.";
	else if (vendor == 3937) vendorText = "Varian Inc.";
	else if (vendor == 3938) vendorText = "Acrox Technologies Co., Ltd.";
	else if (vendor == 3944) vendorText = "TEPCO UQUEST, LTD.";
	else if (vendor == 3945) vendorText = "DIONEX CORPORATION";
	else if (vendor == 3946) vendorText = "Vibren Technologies Inc.";
	else if (vendor == 3955) vendorText = "DFI";
	else if (vendor == 3964) vendorText = "DQ Technology, Inc.";
	else if (vendor == 3965) vendorText = "NetBotz, Inc.";
	else if (vendor == 3966) vendorText = "Fluke Networks Corporation";
	else if (vendor == 3976) vendorText = "VTech Holdings Ltd.";
	else if (vendor == 3979) vendorText = "Yazaki Corporation";
	else if (vendor == 3980) vendorText = "Young Generation International Corp.";
	else if (vendor == 3981) vendorText = "Uniwill Computer Corp.";
	else if (vendor == 3982) vendorText = "Kingnet Technology Co., Ltd.";
	else if (vendor == 3983) vendorText = "SOMA NETWORKS";
	else if (vendor == 3991) vendorText = "CviLux Corporation";
	else if (vendor == 3992) vendorText = "CYBERBANK CORP.";
	else if (vendor == 3998) vendorText = "Lucent Technologies";
	else if (vendor == 4003) vendorText = "Chief Land STARCONN Electronic Co., Ltd.";
	else if (vendor == 4004) vendorText = "ATL Technology";
	else if (vendor == 4005) vendorText = "SOTEC CO., LTD.";
	else if (vendor == 4007) vendorText = "EPOX COMPUTER CO., LTD.";
	else if (vendor == 4008) vendorText = "Logic Controls, Inc.";
	else if (vendor == 4015) vendorText = "Winpoint Electronic Corp.";
	else if (vendor == 4016) vendorText = "Haurtian Wire & Cable Co., Ltd.";
	else if (vendor == 4017) vendorText = "Inclose Design Inc.";
	else if (vendor == 4018) vendorText = "Conteck Co., Ltd.";
	else if (vendor == 4024) vendorText = "Wistron Corporation";
	else if (vendor == 4025) vendorText = "AACOM CORPORATION";
	else if (vendor == 4026) vendorText = "SAN SHING ELECTRONICS CO., LTD..";
	else if (vendor == 4027) vendorText = "Bitwise Systems, Inc.";
	else if (vendor == 4033) vendorText = "MITAC INTERNATIONAL CORP.";
	else if (vendor == 4034) vendorText = "PLUG AND JACK INDUSTRIAL INC.";
	else if (vendor == 4038) vendorText = "Dataplus Supplies, Inc.";
	else if (vendor == 4046) vendorText = "Sony Ericsson Mobile Communications AB";
	else if (vendor == 4047) vendorText = "Dynastream Innovations Inc.";
	else if (vendor == 4048) vendorText = "Tulip Computers B.V.";
	else if (vendor == 4052) vendorText = "Tenovis GmbH & Co., KG";
	else if (vendor == 4053) vendorText = "Direct Access Technology, Inc.";
	else if (vendor == 4060) vendorText = "Micro Plus";
	else if (vendor == 4068) vendorText = "IN-TECH ELECTRONICS LIMITED";
	else if (vendor == 4069) vendorText = "TC&C ELECTRONIC CO.,LTD (SUNTECC, INC.)";
	else if (vendor == 4074) vendorText = "United Computer Accessories";
	else if (vendor == 4075) vendorText = "CRS ELECTRONIC CO., LTD.";
	else if (vendor == 4076) vendorText = "UMC Electronics Co., Ltd.";
	else if (vendor == 4077) vendorText = "ACCESS CO., LTD.";
	else if (vendor == 4078) vendorText = "Xsido Corporation";
	else if (vendor == 4079) vendorText = "MJ RESEARCH, INC.";
	else if (vendor == 4086) vendorText = "Core Valley Co., Ltd.";
	else if (vendor == 4087) vendorText = "CHI SHING COMPUTER ACCESSORIES CO., LTD.";
	else if (vendor == 4095) vendorText = "Aopen Inc.";
	else if (vendor == 4096) vendorText = "Speed Tech Corp.";
	else if (vendor == 4097) vendorText = "Ritronics Components (S) Pte. Ltd.";
	else if (vendor == 4099) vendorText = "SIGMA CORPORATION";
	else if (vendor == 4100) vendorText = "LG Electronics Inc.";
	else if (vendor == 4101) vendorText = "Apacer Technology Animeta Systems Inc.";
	else if (vendor == 4105) vendorText = "Lumanate, Inc.";
	else if (vendor == 4106) vendorText = "AV Chaseway Ltd.";
	else if (vendor == 4107) vendorText = "Chou Chin Industrial Co., Ltd.";
	else if (vendor == 4109) vendorText = "NETOPIA, INC.";
	else if (vendor == 4112) vendorText = "FUKUDA DENSHI CO., LTD.";
	else if (vendor == 4113) vendorText = "Mobile Media Tech.";
	else if (vendor == 4114) vendorText = "SDKM Fibres, Wires & Cables Berhad";
	else if (vendor == 4115) vendorText = "TST-Touchless Sensor Technology AG";
	else if (vendor == 4116) vendorText = "Densitron Technologies PLC";
	else if (vendor == 4117) vendorText = "Softronics Pty. Ltd.";
	else if (vendor == 4118) vendorText = "Xiamen Hung's Enterprise Co., Ltd.";
	else if (vendor == 4119) vendorText = "SPEEDY INDUSTRIAL SUPPLIES PTE. LTD.";
	else if (vendor == 4130) vendorText = "Shinko Shoji Co., Ltd.";
	else if (vendor == 4133) vendorText = "Hyper-PALTEK";
	else if (vendor == 4134) vendorText = "Newly Corporation";
	else if (vendor == 4135) vendorText = "Time Domain";
	else if (vendor == 4136) vendorText = "Inovys Corporation";
	else if (vendor == 4137) vendorText = "Atlantic Coast Telesys";
	else if (vendor == 4138) vendorText = "RAMOS Technology Co., Ltd.";
	else if (vendor == 4139) vendorText = "Infotronic America, Inc.";
	else if (vendor == 4140) vendorText = "Etoms Electronics Corp.";
	else if (vendor == 4141) vendorText = "Winic Corporation";
	else if (vendor == 4143) vendorText = "WENZHOU YIHUA COMMUNICATED CONNECTOR CO., LTD.";
	else if (vendor == 4145) vendorText = "Comax Technology Inc.";
	else if (vendor == 4146) vendorText = "C-One Technology Corp.";
	else if (vendor == 4147) vendorText = "Nucam Corporation";
	else if (vendor == 4163) vendorText = "iCreate Technologies Corporation";
	else if (vendor == 4164) vendorText = "Chu Yuen Enterprise Co., Ltd.";
	else if (vendor == 4168) vendorText = "Targus Group International";
	else if (vendor == 4172) vendorText = "AMCO TEC International Inc.";
	else if (vendor == 4179) vendorText = "Immanuel Electronics Co., Ltd.";
	else if (vendor == 4180) vendorText = "BMS International Beheer N.V.";
	else if (vendor == 4181) vendorText = "Complex Micro Interconnection Co., Ltd.";
	else if (vendor == 4182) vendorText = "Hsin Chen Ent Co., Ltd.";
	else if (vendor == 4183) vendorText = "ON Semiconductor";
	else if (vendor == 4184) vendorText = "Western Digital Technologies, Inc.";
	else if (vendor == 4185) vendorText = "Giesecke & Devrient GmbH";
	else if (vendor == 4188) vendorText = "Freeway Electronic Wire & Cable (Dongguan) Co., Ltd.";
	else if (vendor == 4189) vendorText = "Delkin Devices, Inc.";
	else if (vendor == 4190) vendorText = "Valence Semiconductor Design Limited";
	else if (vendor == 4191) vendorText = "Chin Shong Enterprise Co., Ltd.";
	else if (vendor == 4192) vendorText = "Easthome Industrial Co., Ltd.";
	else if (vendor == 4202) vendorText = "Loyal Legend Limited";
	else if (vendor == 4204) vendorText = "Curitel Communications, Inc.";
	else if (vendor == 4205) vendorText = "San Chieh Manufacturing Ltd.";
	else if (vendor == 4206) vendorText = "ConectL";
	else if (vendor == 4207) vendorText = "Money Controls";
	else if (vendor == 4214) vendorText = "GCT Semiconductor, Inc.";
	else if (vendor == 4222) vendorText = "MIDORIYA ELECTRIC CO., LTD.";
	else if (vendor == 4223) vendorText = "KidzMouse, Inc.";
	else if (vendor == 4226) vendorText = "Shin-Etsukaken Co., Ltd.";
	else if (vendor == 4227) vendorText = "CANON ELECTRONICS INC.";
	else if (vendor == 4228) vendorText = "PANTECH CO., LTD.";
	else if (vendor == 4234) vendorText = "Chloride Power Protection";
	else if (vendor == 4235) vendorText = "Grand-tek Technology Co., Ltd.";
	else if (vendor == 4236) vendorText = "Robert Bosch GmbH";
	else if (vendor == 4238) vendorText = "Lotes Co., Ltd.";
	else if (vendor == 4249) vendorText = "Surface Optics Corporation";
	else if (vendor == 4255) vendorText = "eSOL Co., Ltd.";
	else if (vendor == 4256) vendorText = "HIROTECH, INC.";
	else if (vendor == 4259) vendorText = "MITSUBISHI MATERIALS CORPORATION";
	else if (vendor == 4265) vendorText = "SK Teletech Co., Ltd.";
	else if (vendor == 4266) vendorText = "Cables To Go";
	else if (vendor == 4267) vendorText = "Universal Global Scientific Industrial (USI) Co., Ltd.";
	else if (vendor == 4268) vendorText = "Honeywell, Inc.";
	else if (vendor == 4270) vendorText = "Princeton Technology Corp.";
	else if (vendor == 4277) vendorText = "Comodo";
	else if (vendor == 4283) vendorText = "TM Technology Inc.";
	else if (vendor == 4284) vendorText = "Dinging Technology Co., Ltd.";
	else if (vendor == 4285) vendorText = "TMT TECHNOLOGY, INC.";
	else if (vendor == 4292) vendorText = "Silicon Laboratories, Inc.";
	else if (vendor == 4293) vendorText = "Sanei Electric Inc.";
	else if (vendor == 4294) vendorText = "Intec, Inc.";
	else if (vendor == 4299) vendorText = "eratech";
	else if (vendor == 4300) vendorText = "GBM Connector Co., Ltd.";
	else if (vendor == 4301) vendorText = "Kycon Inc.";
	else if (vendor == 4308) vendorText = "Man Boon Manufactory Ltd.";
	else if (vendor == 4309) vendorText = "Uni Class Technology Co., Ltd.";
	else if (vendor == 4310) vendorText = "Actions Semiconductor Co., Ltd.";
	else if (vendor == 4318) vendorText = "Authenex, Inc.";
	else if (vendor == 4319) vendorText = "In-Win Development Inc.";
	else if (vendor == 4320) vendorText = "Bella Corporation";
	else if (vendor == 4321) vendorText = "CABLEPLUS LTD.";
	else if (vendor == 4322) vendorText = "Nada Electronics, Ltd.";
	else if (vendor == 4332) vendorText = "Vast Technologies Inc.";
	else if (vendor == 4347) vendorText = "Pictos Technologies, Inc.";
	else if (vendor == 4352) vendorText = "VirTouch Ltd.";
	else if (vendor == 4353) vendorText = "EASYPASS INDUSTRIAL CO., LTD.";
	else if (vendor == 4360) vendorText = "BRIGHTCOM TECHNOLOGIES LTD.";
	else if (vendor == 4362) vendorText = "Moxa Inc.";
	else if (vendor == 4368) vendorText = "Analog Devices Canada Ltd.";
	else if (vendor == 4370) vendorText = "Golden Bright (Sichuan) YM ELECTRIC CO., LTD.";
	else if (vendor == 4371) vendorText = "Medion AG";
	else if (vendor == 4381) vendorText = "Centon Electronics";
	else if (vendor == 4382) vendorText = "VSO Electric Co., Ltd.";
	else if (vendor == 4398) vendorText = "Master Hill Electric Wire and Cable Co., Ltd.";
	else if (vendor == 4399) vendorText = "Cellon International";
	else if (vendor == 4400) vendorText = "Tenx Technology, Inc.";
	else if (vendor == 4401) vendorText = "Integrated System Solution Corp.";
	else if (vendor == 4412) vendorText = "Arin Tech Co., Ltd.";
	else if (vendor == 4413) vendorText = "Mapower Electronics Co. Ltd.";
	else if (vendor == 4417) vendorText = "V ONE MULTIMEDIA PTE LTD";
	else if (vendor == 4422) vendorText = "Shimane SANYO Electric Co., Ltd.";
	else if (vendor == 4423) vendorText = "Ever Great Electric Wire and Cable Co., Ltd.";
	else if (vendor == 4427) vendorText = "Sphairon Technologies GmbH";
	else if (vendor == 4428) vendorText = "Tinius Olsen Testing Machine Co., Inc.";
	else if (vendor == 4429) vendorText = "Alpha Imaging Technology Corp.";
	else if (vendor == 4443) vendorText = "Salix Technology Co., Ltd.";
	else if (vendor == 4450) vendorText = "Secugen Corporation";
	else if (vendor == 4451) vendorText = "DeLorme Publishing Inc.";
	else if (vendor == 4452) vendorText = "YUAN High-Tech Development Co., Ltd.";
	else if (vendor == 4453) vendorText = "Telson Electronics Co., Ltd.";
	else if (vendor == 4454) vendorText = "Bantam Interactive Technologies";
	else if (vendor == 4455) vendorText = "Salient Systems Corporation";
	else if (vendor == 4456) vendorText = "BizConn International Corp.";
	else if (vendor == 4462) vendorText = "Gigastorage Corp.";
	else if (vendor == 4463) vendorText = "Silicon 10 Technology Corp.";
	else if (vendor == 4469) vendorText = "Shengyih Steel Mold Co., Ltd.";
	else if (vendor == 4477) vendorText = "Santa Electronic Inc.";
	else if (vendor == 4478) vendorText = "JNC, Inc.";
	else if (vendor == 4482) vendorText = "Venture Corporation Limited";
	else if (vendor == 4483) vendorText = "Digital Dream Co. Europe Ltd.";
	else if (vendor == 4484) vendorText = "Kyocera Elco Corporation";
	else if (vendor == 4488) vendorText = "Bloomberg L.P.";
	else if (vendor == 4489) vendorText = "Trisat Industrial Co., Ltd.";
	else if (vendor == 4495) vendorText = "You Yang Technology Co., Ltd.";
	else if (vendor == 4496) vendorText = "Tripace";
	else if (vendor == 4497) vendorText = "Loyalty Founder Enterprise Co., Ltd.";
	else if (vendor == 4503) vendorText = "Technoimagia Co., Ltd.";
	else if (vendor == 4504) vendorText = "StarShine Technology Corp.";
	else if (vendor == 4505) vendorText = "Sierra Wireless Inc.";
	else if (vendor == 4506) vendorText = "DONG GUAN JALINK ZHAN QI Technology Co., Ltd.";
	else if (vendor == 4515) vendorText = "Technovas Co., Ltd.";
	else if (vendor == 4520) vendorText = "Hoeft & Wessel AG";
	else if (vendor == 4522) vendorText = "GlobalMedia Group, LLC";
	else if (vendor == 4523) vendorText = "Exito Electronics Co., Ltd.";
	else if (vendor == 4527) vendorText = "Valence Semiconductor";
	else if (vendor == 4528) vendorText = "ATECH FLASH TECHNOLOGY";
	else if (vendor == 4529) vendorText = "New Motion Tec. Corp.";
	else if (vendor == 4544) vendorText = "Sanmos Microelectronics Corp.";
	else if (vendor == 4552) vendorText = "Fullcom Technology Corp.";
	else if (vendor == 4553) vendorText = "Monster Cable Products, Inc.";
	else if (vendor == 4559) vendorText = "Nemoto Kyorindo Co., Ltd.";
	else if (vendor == 4566) vendorText = "FUJIFILM AXIA CO., LTD.";
	else if (vendor == 4571) vendorText = "Topfield Co., Ltd.";
	else if (vendor == 4581) vendorText = "CHUFON Technology Co., Ltd.";
	else if (vendor == 4582) vendorText = "K.I. Technology Co. Ltd.";
	else if (vendor == 4583) vendorText = "Rockford Corporation";
	else if (vendor == 4584) vendorText = "NAAT Technology Corp.";
	else if (vendor == 4585) vendorText = "Wincan Technology Co., Ltd.";
	else if (vendor == 4586) vendorText = "PAN RAM International Corp.";
	else if (vendor == 4587) vendorText = "VTech Innovation L.P. dba Advanced American Telephones";
	else if (vendor == 4588) vendorText = "Hitachi Computer Peripherals Co., Ltd.";
	else if (vendor == 4591) vendorText = "Cableplus Industrial Co., Ltd.";
	else if (vendor == 4597) vendorText = "Siemens Mobile Phones";
	else if (vendor == 4610) vendorText = "KUK JE TONG SHIN CO., LTD.";
	else if (vendor == 4622) vendorText = "HUDSON SOFT CO., LTD.";
	else if (vendor == 4631) vendorText = "Goyatek Technology Inc.";
	else if (vendor == 4632) vendorText = "Geutebrueck GmbH";
	else if (vendor == 4633) vendorText = "COMPAL COMMUNICATIONS, INC.";
	else if (vendor == 4638) vendorText = "Jungsoft Co., Ltd.";
	else if (vendor == 4643) vendorText = "SKYCABLE ENTERPRISE CO., LTD.";
	else if (vendor == 4649) vendorText = "EPO Science & Technology Inc.";
	else if (vendor == 4655) vendorText = "Takasic";
	else if (vendor == 4656) vendorText = "Chipidea-Microelectronica, S.A.";
	else if (vendor == 4657) vendorText = "CHI MEI COMMUNICATION SYSTEMS, INC.";
	else if (vendor == 4667) vendorText = "De La Rue Systems Automatizacao";
	else if (vendor == 4668) vendorText = "K-Won C & C Co., Ltd.";
	else if (vendor == 4674) vendorText = "MAC SYSTEM CO., LTD.";
	else if (vendor == 4682) vendorText = "AirVast Technology Inc.";
	else if (vendor == 4683) vendorText = "NYKO Technologies, Inc.";
	else if (vendor == 4689) vendorText = "Iwaya Corporation";
	else if (vendor == 4690) vendorText = "Nextway Co., Ltd.";
	else if (vendor == 4691) vendorText = "Erebus Limited";
	else if (vendor == 4698) vendorText = "Shintake Sangyo Co., Ltd.";
	else if (vendor == 4703) vendorText = "ADATA Technology Co., Ltd.";
	else if (vendor == 4705) vendorText = "All Ring Tech Co., Ltd.";
	else if (vendor == 4706) vendorText = "MICRO VISION CO., LTD.";
	else if (vendor == 4707) vendorText = "Opti Japan Corporation";
	else if (vendor == 4708) vendorText = "Covidien Energy-based Devices";
	else if (vendor == 4715) vendorText = "Veridian Systems";
	else if (vendor == 4716) vendorText = "Aristocrat Technologies";
	else if (vendor == 4717) vendorText = "Bel Stewart";
	else if (vendor == 4718) vendorText = "Strobe Data, Inc.";
	else if (vendor == 4719) vendorText = "TwinMOS Technologies Inc.";
	else if (vendor == 4720) vendorText = "Procomp Informatics Ltd.";
	else if (vendor == 4721) vendorText = "Foxda Technology Industrial (Shenzhen) Co., Ltd.";
	else if (vendor == 4722) vendorText = "Linear Technology Corporation";
	else if (vendor == 4736) vendorText = "Animeta Systems Inc.";
	else if (vendor == 4737) vendorText = "Gean Sen Electronic Co., Ltd.";
	else if (vendor == 4742) vendorText = "MARVELL SEMICONDUCTOR, INC.";
	else if (vendor == 4753) vendorText = "Flarion Technologies";
	else if (vendor == 4754) vendorText = "Fire International Ltd.";
	else if (vendor == 4756) vendorText = "RISO KAGAKU CORP.";
	else if (vendor == 4763) vendorText = "CyberTAN Technology Inc.";
	else if (vendor == 4764) vendorText = "Min Aik Technology Co., Ltd.";
	else if (vendor == 4765) vendorText = "Yueqing Longhua Electronics Factory";
	else if (vendor == 4771) vendorText = "KENT WORLD CO., LTD.";
	else if (vendor == 4772) vendorText = "Guangdong Matsunichi Communications Technology Co., Ltd";
	else if (vendor == 4775) vendorText = "Trendchip Technologies Corp.";
	else if (vendor == 4779) vendorText = "Honey Bee Electronic International Ltd.";
	else if (vendor == 4781) vendorText = "Asahi Seiko Co., Ltd.";
	else if (vendor == 4786) vendorText = "DICKSON Company";
	else if (vendor == 4787) vendorText = "Megaforce Company Ltd.";
	else if (vendor == 4792) vendorText = "Zhejiang Xinya Electronic Technology Co., Ltd.";
	else if (vendor == 4793) vendorText = "Freehand Systems, Inc.";
	else if (vendor == 4794) vendorText = "Sony Computer Entertainment America";
	else if (vendor == 4797) vendorText = "Sun Light Application Co., Ltd.";
	else if (vendor == 4809) vendorText = "Newmen Technology Corp. Ltd.";
	else if (vendor == 4817) vendorText = "Huawei Technologies Co., Ltd.";
	else if (vendor == 4818) vendorText = "LINE TECH INDUSTRIAL CO., LTD.";
	else if (vendor == 4823) vendorText = "Better Wire Factory Holdings (HK) Limited";
	else if (vendor == 4824) vendorText = "Araneus Information Systems Oy";
	else if (vendor == 4825) vendorText = "DIGITFAB INTERNATIONAL CO., LTD.";
	else if (vendor == 4829) vendorText = "Alec Electronics Co.,Ltd.";
	else if (vendor == 4830) vendorText = "National Display Systems";
	else if (vendor == 4836) vendorText = "Bruel & Kjaer Sound & Vibration Meas. A/S";
	else if (vendor == 4841) vendorText = "Mindspeed Technologies";
	else if (vendor == 4852) vendorText = "Glovic Electronics Corp.";
	else if (vendor == 4853) vendorText = "Dynamic System Electronics Corp.";
	else if (vendor == 4855) vendorText = "Memorex Products, Inc.";
	else if (vendor == 4857) vendorText = "RF-LINK SYSTEMS, INC.";
	else if (vendor == 4858) vendorText = "RF Micro Devices";
	else if (vendor == 4862) vendorText = "E.U CONNECTOR(M) SDN BHD.";
	else if (vendor == 4870) vendorText = "Torcon Instruments Inc.";
	else if (vendor == 4871) vendorText = "USBest Technology Inc.";
	else if (vendor == 4882) vendorText = "ICS Electronics";
	else if (vendor == 4887) vendorText = "PC-CRAFT Co., Ltd.";
	else if (vendor == 4888) vendorText = "O'RITE TECHNOLOGY Co., Ltd.";
	else if (vendor == 4895) vendorText = "Ayuttha Technology Corp.";
	else if (vendor == 4899) vendorText = "Zeustech Company Limited";
	else if (vendor == 4900) vendorText = "H-Mod, Inc.";
	else if (vendor == 4905) vendorText = "Appairent Technologies, Inc.";
	else if (vendor == 4906) vendorText = "Envara";
	else if (vendor == 4907) vendorText = "Konica Minolta, Inc.";
	else if (vendor == 4908) vendorText = "Le Prestique International (H.K.) Ltd.";
	else if (vendor == 4923) vendorText = "FLASH SUPPORT GROUP, INC.";
	else if (vendor == 4924) vendorText = "G-Design Technology";
	else if (vendor == 4930) vendorText = "Sutter Instrument Company";
	else if (vendor == 4933) vendorText = "Sino Lite Technology Corp.";
	else if (vendor == 4936) vendorText = "Katsuragawa Electric Co., Ltd.";
	else if (vendor == 4950) vendorText = "Techpoint Electric Wire & Cable Co., Ltd.";
	else if (vendor == 4955) vendorText = "M-System Co., Ltd.";
	else if (vendor == 4970) vendorText = "Pelco";
	else if (vendor == 4971) vendorText = "STEC SimpleTech";
	else if (vendor == 4972) vendorText = "Datastor Technology Co., Ltd.";
	else if (vendor == 4976) vendorText = "Swissbit AG";
	else if (vendor == 4980) vendorText = "American Anko Co.";
	else if (vendor == 4981) vendorText = "TCL MOBILE COMMUNICATION CO., LTD.";
	else if (vendor == 4982) vendorText = "Vimtron Electronics Co., Ltd.";
	else if (vendor == 4989) vendorText = "Pericom Semiconductor Corp.";
	else if (vendor == 5008) vendorText = "TomTom International B.V.";
	else if (vendor == 5054) vendorText = "Ricoh Printing Systems, Ltd.";
	else if (vendor == 5066) vendorText = "JyeTai Precision Industrial Co., Ltd.";
	else if (vendor == 5071) vendorText = "Wisair Ltd.";
	else if (vendor == 5073) vendorText = "A-Max Technology Macao Commercial Offshore Co. Ltd.";
	else if (vendor == 5075) vendorText = "AzureWave Technologies, Inc.";
	else if (vendor == 5084) vendorText = "ALEREON, INC.";
	else if (vendor == 5085) vendorText = "i.Tech Dynamic Limited";
	else if (vendor == 5089) vendorText = "Kaibo Wire & Cable (Shenzhen) Co., Ltd.";
	else if (vendor == 5117) vendorText = "Initio Corporation";
	else if (vendor == 5118) vendorText = "Phison Electronics Corp.";
	else if (vendor == 5122) vendorText = "Bowe Bell & Howell";
	else if (vendor == 5134) vendorText = "Telechips, Inc.";
	else if (vendor == 5136) vendorText = "Novatel Wireless, Inc.";
	else if (vendor == 5145) vendorText = "ABILITY ENTERPRISE CO., LTD.";
	else if (vendor == 5148) vendorText = "Leviton Manufacturing";
	else if (vendor == 5153) vendorText = "Sensor Technologies America, Inc.";
	else if (vendor == 5161) vendorText = "Vega Technologies Industrial (Austria) Co.";
	else if (vendor == 5168) vendorText = "RedOctane";
	else if (vendor == 5169) vendorText = "Pertech Resources, Inc.";
	else if (vendor == 5173) vendorText = "Wistron NeWeb Corp.";
	else if (vendor == 5174) vendorText = "Denali Software, Inc.";
	else if (vendor == 5180) vendorText = "Altek Corporation";
	else if (vendor == 5206) vendorText = "Extending Wire & Cable Co., Ltd.";
	else if (vendor == 5217) vendorText = "Staccato Communications";
	else if (vendor == 5234) vendorText = "Hangzhou H3C Technologies Co., Ltd.";
	else if (vendor == 5242) vendorText = "Formosa21 Industrial Computing Inc.";
	else if (vendor == 5246) vendorText = "UPEK Inc.";
	else if (vendor == 5247) vendorText = "Hama GmbH & Co., KG";
	else if (vendor == 5255) vendorText = "DSP Group, Ltd.";
	else if (vendor == 5262) vendorText = "EVATRONIX SA";
	else if (vendor == 5271) vendorText = "Panstrong Company Ltd.";
	else if (vendor == 5293) vendorText = "CTK Corporation";
	else if (vendor == 5294) vendorText = "Printronix Inc.";
	else if (vendor == 5295) vendorText = "ATP Electronics Inc.";
	else if (vendor == 5296) vendorText = "StarTech.com Ltd.";
	else if (vendor == 5312) vendorText = "Rockwell Automation, Inc.";
	else if (vendor == 5314) vendorText = "Gemlight Computer Ltd.";
	else if (vendor == 5325) vendorText = "MOAI ELECTRONICS CORPORATION";
	else if (vendor == 5336) vendorText = "JAMER INDUSTRIES CO., LTD.";
	else if (vendor == 5349) vendorText = "SAIN Information & Communications Co., Ltd.";
	else if (vendor == 5357) vendorText = "Shure Inc.";
	else if (vendor == 5375) vendorText = "Twinhead International Corp.";
	else if (vendor == 5376) vendorText = "Ellisys";
	else if (vendor == 5377) vendorText = "Pine-Tum Enterprise Co., Ltd.";
	else if (vendor == 5393) vendorText = "BridgeCo, AG";
	else if (vendor == 5398) vendorText = "Skymedi Corporation";
	else if (vendor == 5404) vendorText = "VeriSilicon Holdings Co., Ltd.";
	else if (vendor == 5408) vendorText = "Bitwire Corp.";
	else if (vendor == 5421) vendorText = "JMicron Technology Corp.";
	else if (vendor == 5422) vendorText = "HLDS (Hitachi-LG Data Storage, Inc.)";
	else if (vendor == 5440) vendorText = "Phihong Technology Co., Ltd.";
	else if (vendor == 5451) vendorText = "PNY Technologies Inc.";
	else if (vendor == 5453) vendorText = "ConnectCounty Holdings Berhad";
	else if (vendor == 5454) vendorText = "Rapid Connect D & M Holdings, Inc.";
	else if (vendor == 5460) vendorText = "Prolink Microsystems Corporation";
	else if (vendor == 5480) vendorText = "Sunf Pu Technology Co., Ltd";
	else if (vendor == 5487) vendorText = "Quantum Corporation";
	else if (vendor == 5488) vendorText = "ALLTOP TECHNOLOGY CO., LTD.";
	else if (vendor == 5499) vendorText = "Ketron SRL";
	else if (vendor == 5502) vendorText = "U-MEDIA Communications, Inc.";
	else if (vendor == 5510) vendorText = "Palconn Sitor Electronics (Shenzhen) Co., Ltd.";
	else if (vendor == 5511) vendorText = "SMA Technologie AG";
	else if (vendor == 5517) vendorText = "Oakley Inc.";
	else if (vendor == 5528) vendorText = "Kunshan Guoji Electronics Co., Ltd.";
	else if (vendor == 5538) vendorText = "Freescale Semiconductor, Inc.";
	else if (vendor == 5540) vendorText = "Afa Technologies, Inc.";
	else if (vendor == 5544) vendorText = "Shen Zhen Teamspower Electronics Co., Ltd.";
	else if (vendor == 5546) vendorText = "DongGuan Ya Lian Hong Kong Gearway Electronics Co., Ltd.";
	else if (vendor == 5577) vendorText = "D-Box Technologies";
	else if (vendor == 5589) vendorText = "Coulomb Electronics Ltd.";
	else if (vendor == 5593) vendorText = "Apexone Microelectronics Inc.";
	else if (vendor == 5596) vendorText = "Hynix Semiconductor Inc.";
	else if (vendor == 5600) vendorText = "Seong Ji Industrial Co., Ltd.";
	else if (vendor == 5609) vendorText = "Pacific Digital Corp.";
	else if (vendor == 5612) vendorText = "Belcarra Technologies Corp.";
	else if (vendor == 5638) vendorText = "UMAX";
	else if (vendor == 5640) vendorText = "Inside Out Networks";
	else if (vendor == 5645) vendorText = "Samtec";
	else if (vendor == 5650) vendorText = "Soft DB Inc.";
	else if (vendor == 5657) vendorText = "L & K Precision Technology Co., Ltd.";
	else if (vendor == 5665) vendorText = "Wionics Research";
	else if (vendor == 5672) vendorText = "Stonestreet One, Inc.";
	else if (vendor == 5679) vendorText = "WiQuest Communications, Inc.";
	else if (vendor == 5681) vendorText = "Focus Enhancements";
	else if (vendor == 5694) vendorText = "HongLin Electronics Co., Ltd.";
	else if (vendor == 5706) vendorText = "ChipX";
	else if (vendor == 5728) vendorText = "Creatix Polymedia GmbH";
	else if (vendor == 5736) vendorText = "Actiontec Electronics, Inc.";
	else if (vendor == 5753) vendorText = "Total Phase";
	else if (vendor == 5762) vendorText = "Maxwise Production Enterprise Ltd.";
	else if (vendor == 5764) vendorText = "Godspeed Computer Corp.";
	else if (vendor == 5766) vendorText = "ZOOM Corporation";
	else if (vendor == 5767) vendorText = "Kingmax Digital Inc.";
	else if (vendor == 5782) vendorText = "Hitachi Video and Information System, Inc.";
	else if (vendor == 5783) vendorText = "VTEC TEST, INC.";
	else if (vendor == 5797) vendorText = "Shenzhen Zhengerya Technology Co., Ltd.";
	else if (vendor == 5804) vendorText = "Dongguan ChingLung Wire & Cable Co., Ltd.";
	else if (vendor == 5836) vendorText = "silex technology, Inc.";
	else if (vendor == 5843) vendorText = "Frontline Test Equipment, Inc.";
	else if (vendor == 5855) vendorText = "King Billion Electronics Co., Ltd.";
	else if (vendor == 5877) vendorText = "Futurelogic Inc.";
	else if (vendor == 5895) vendorText = "ARTIMI";
	else if (vendor == 5901) vendorText = "Avnera";
	else if (vendor == 5942) vendorText = "CANON IMAGING SYSTEMS INC.";
	else if (vendor == 5943) vendorText = "Hong Kong Applied Science and Technology Research Inst.";
	else if (vendor == 5946) vendorText = "F. Hoffmann-La Roche AG";
	else if (vendor == 5955) vendorText = "General Atomics";
	else if (vendor == 5960) vendorText = "MQP Electronics Ltd.";
	else if (vendor == 5964) vendorText = "ASMedia Technology Inc.";
	else if (vendor == 5977) vendorText = "LucidPort Technology, Inc.";
	else if (vendor == 5998) vendorText = "UD electronic corp.";
	else if (vendor == 6001) vendorText = "Shenzhen Alex Connector Co., Ltd.";
	else if (vendor == 6002) vendorText = "System Level Solutions, Inc.";
	else if (vendor == 6018) vendorText = "Spreadtrum Hong Kong Limited";
	else if (vendor == 6020) vendorText = "TopSeed Technology Corp.";
	else if (vendor == 6024) vendorText = "ShenZhen Litkconn Technology Co., Ltd.";
	else if (vendor == 6038) vendorText = "Printrex, Inc.";
	else if (vendor == 6039) vendorText = "JALCO CO., LTD.";
	else if (vendor == 6053) vendorText = "Advanced Connection Technology Inc.";
	else if (vendor == 6055) vendorText = "MICOMSOFT CO., LTD.";
	else if (vendor == 6083) vendorText = "Singim International Corp.";
	else if (vendor == 6095) vendorText = "Hip Hing Cable & Plug Mfy. Ltd.";
	else if (vendor == 6096) vendorText = "Sanford L.P.";
	else if (vendor == 6099) vendorText = "Korea Techtron Co., Ltd.";
	else if (vendor == 6121) vendorText = "DisplayLink (UK) Ltd.";
	else if (vendor == 6127) vendorText = "Lenovo";
	else if (vendor == 6133) vendorText = "K.K. Rocky";
	else if (vendor == 6134) vendorText = "Unicomp, Inc";
	else if (vendor == 6160) vendorText = "Wanshih Electronic Co., Ltd.";
	else if (vendor == 6168) vendorText = "Osteosys Co., Ltd.";
	else if (vendor == 6185) vendorText = "Dongguan Suzhou YuQiu Technology Co., Ltd.";
	else if (vendor == 6193) vendorText = "Gwo Jinn Industries Co., Ltd.";
	else if (vendor == 6194) vendorText = "Huizhou Shenghua Industrial Co., Ltd.";
	else if (vendor == 6228) vendorText = "Memory Devices Ltd.";
	else if (vendor == 6241) vendorText = "Tech Technology Industrial Company";
	else if (vendor == 6242) vendorText = "Teridian Semiconductor Corp.";
	else if (vendor == 6257) vendorText = "Aveo Technology Corp.";
	else if (vendor == 6271) vendorText = "Siano Mobile Silicon Ltd.";
	else if (vendor == 6292) vendorText = "SyntheSys Research, Inc.";
	else if (vendor == 6296) vendorText = "Summit Microelectronics";
	else if (vendor == 6297) vendorText = "Linkiss Co., Ltd.";
	else if (vendor == 6326) vendorText = "Mikkon Technology Limited";
	else if (vendor == 6351) vendorText = "Tung Shu Mei Industrial Co., Ltd.";
	else if (vendor == 6353) vendorText = "Google Inc.";
	else if (vendor == 6357) vendorText = "Starline International Group Limited";
	else if (vendor == 6371) vendorText = "Fitilink Integrated Technology, Inc.";
	else if (vendor == 6394) vendorText = "Kuang Ying Computer Equipment Co., Ltd.";
	else if (vendor == 6397) vendorText = "FineArch Inc.";
	else if (vendor == 6413) vendorText = "Motorola GSG";
	else if (vendor == 6420) vendorText = "Alco Digital Devices Limited";
	else if (vendor == 6421) vendorText = "Nordic Semiconductor ASA";
	else if (vendor == 6425) vendorText = "Pixelworks";
	else if (vendor == 6434) vendorText = "Power 7 Technologies Corp.";
	else if (vendor == 6447) vendorText = "Avago Technologies, Pte.";
	else if (vendor == 6448) vendorText = "Shenzhen Xianhe Technology Co., Ltd.";
	else if (vendor == 6449) vendorText = "Ningbo Broad Telecommunication Co., Ltd.";
	else if (vendor == 6473) vendorText = "Lab126";
	else if (vendor == 6481) vendorText = "Hyperstone GmbH";
	else if (vendor == 6483) vendorText = "Ironkey Inc.";
	else if (vendor == 6487) vendorText = "BIOS Corporation";
	else if (vendor == 6503) vendorText = "CASIO HITACHI Mobile Communications Co., Ltd.";
	else if (vendor == 6507) vendorText = "Wispro Technology Inc.";
	else if (vendor == 6512) vendorText = "Dane-Elec Corp. USA";
	else if (vendor == 6537) vendorText = "Nuconn Technology Corp.";
	else if (vendor == 6541) vendorText = "Fairchild Imaging";
	else if (vendor == 6543) vendorText = "Beceem Communications Inc.";
	else if (vendor == 6544) vendorText = "Acron Precision Industrial Co., Ltd.";
	else if (vendor == 6556) vendorText = "Richnex Microelectronics Corporation";
	else if (vendor == 6557) vendorText = "Dexxon Data Media";
	else if (vendor == 6559) vendorText = "Benica Corporation";
	else if (vendor == 6568) vendorText = "Biforst Technology Inc.";
	else if (vendor == 6581) vendorText = "B & W Group";
	else if (vendor == 6582) vendorText = "Infotech Logistic, LLC";
	else if (vendor == 6607) vendorText = "Parrot SA";
	else if (vendor == 6625) vendorText = "WeiDuan Electronic Accessory (S.Z.) Co., Ltd.";
	else if (vendor == 6632) vendorText = "Industrial Technology Research Institute";
	else if (vendor == 6639) vendorText = "Pak Heng Technology (Shenzhen) Co., Ltd.";
	else if (vendor == 6640) vendorText = "Jyh Woei Industrial Co., Ltd.";
	else if (vendor == 6655) vendorText = "Best Buy China Ltd.";
	else if (vendor == 6666) vendorText = "USB-IF non-workshop";
	else if (vendor == 6674) vendorText = "KES Co., Ltd.";
	else if (vendor == 6693) vendorText = "Amphenol East Asia Ltd.";
	else if (vendor == 6698) vendorText = "Seagate Branded Solutions";
	else if (vendor == 6709) vendorText = "Artesyn Astec Power, a division of Emerson Network Power";
	else if (vendor == 6710) vendorText = "Biwin Technology Ltd.";
	else if (vendor == 6720) vendorText = "TERMINUS TECHNOLOGY INC.";
	else if (vendor == 6721) vendorText = "Action Electronics Co., Ltd.";
	else if (vendor == 6730) vendorText = "Silicon Image";
	else if (vendor == 6731) vendorText = "SafeBoot International B.V.";
	else if (vendor == 6753) vendorText = "Abbott Diabetes Care";
	else if (vendor == 6762) vendorText = "Spansion Inc.";
	else if (vendor == 6765) vendorText = "SamYoung Electronics Co., Ltd";
	else if (vendor == 6766) vendorText = "Global Unichip Corp.";
	else if (vendor == 6767) vendorText = "Sagem Orga GmbH";
	else if (vendor == 6772) vendorText = "Oberthur Technologies";
	else if (vendor == 6777) vendorText = "Bayer Health Care LLC";
	else if (vendor == 6779) vendorText = "Lumberg Connect  GmbH";
	else if (vendor == 6786) vendorText = "Proconn Technology Co., Ltd.";
	else if (vendor == 6793) vendorText = "Dynalith Systems Co., Ltd.";
	else if (vendor == 6794) vendorText = "Simula Technology Inc.";
	else if (vendor == 6795) vendorText = "SGS Taiwan Ltd.";
	else if (vendor == 6808) vendorText = "Leica Camera AG";
	else if (vendor == 6820) vendorText = "Data Drive Thru, Inc.";
	else if (vendor == 6821) vendorText = "UBeacon Technologies, Inc.";
	else if (vendor == 6822) vendorText = "eFortune Technology Corp.";
	else if (vendor == 6830) vendorText = "Johnson Component & Equipments Co., Ltd.";
	else if (vendor == 6859) vendorText = "Salcomp Plc";
	else if (vendor == 6865) vendorText = "Desan Wire Co., Ltd.";
	else if (vendor == 6884) vendorText = "ic-design Reinhard Gottinger GmbH";
	else if (vendor == 6885) vendorText = "Jianduan Technology (Shenzhen) Co., Ltd";
	else if (vendor == 6893) vendorText = "High Top Precision Electronic Co., Ltd.";
	else if (vendor == 6894) vendorText = "Dongguan Chang'an Jinxia SHEN ZHEN Rex Electronics Factory";
	else if (vendor == 6895) vendorText = "Octekconn Incorporation";
	else if (vendor == 6940) vendorText = "CORSAIR MEMORY INC.";
	else if (vendor == 6944) vendorText = "MStar Semiconductor, Inc.";
	else if (vendor == 6946) vendorText = "WiLinx Corp.";
	else if (vendor == 6962) vendorText = "Ugobe Inc.";
	else if (vendor == 6966) vendorText = "ViXS Systems, Inc.";
	else if (vendor == 6983) vendorText = "Energizer Holdings, Inc.";
	else if (vendor == 6984) vendorText = "Plastron Precision Co., Ltd.";
	else if (vendor == 7001) vendorText = "K.S. Terminals Inc.";
	else if (vendor == 7002) vendorText = "Chao Zhou Kai Yuan Electric Co., Ltd.";
	else if (vendor == 7013) vendorText = "The Hong Kong Standards and Testing Centre Ltd.";
	else if (vendor == 7046) vendorText = "Dongguan Guanshang Electronics Co., Ltd.";
	else if (vendor == 7048) vendorText = "ShenMing Electron (Dong Guan) Co., Ltd.";
	else if (vendor == 7054) vendorText = "Amlogic, Inc.";
	else if (vendor == 7055) vendorText = "Super Talent Technology, Inc.";
	else if (vendor == 7062) vendorText = "N-Trig";
	else if (vendor == 7065) vendorText = "Shenzhen Yuanchuan Electronic";
	else if (vendor == 7073) vendorText = "JINQ CHERN ENTERPRISE CO., LTD.";
	else if (vendor == 7099) vendorText = "T & A Mobile Phones";
	else if (vendor == 7108) vendorText = "Ford Motor Co.";
	else if (vendor == 7118) vendorText = "Contac Cable Industrial Limited";
	else if (vendor == 7119) vendorText = "Sunplus Innovation Technology Inc.";
	else if (vendor == 7134) vendorText = "P-TWO INDUSTRIES, INC.";
	else if (vendor == 7151) vendorText = "Shenzhen Tongyuan Network-Communication Cables Co., Ltd";
	else if (vendor == 7152) vendorText = "RealVision Inc.";
	else if (vendor == 7158) vendorText = "Orient Semiconductor Electronics, Ltd.";
	else if (vendor == 7181) vendorText = "Relm Wireless";
	else if (vendor == 7184) vendorText = "Lanterra Industrial Co., Ltd.";
	else if (vendor == 7194) vendorText = "Datel Electronics Ltd.";
	else if (vendor == 7195) vendorText = "Volkswagen of America, Inc.";
	else if (vendor == 7199) vendorText = "Goldvish S.A.";
	else if (vendor == 7200) vendorText = "Fuji Electric Device Technology Co., Ltd.";
	else if (vendor == 7201) vendorText = "ADDMM LLC";
	else if (vendor == 7202) vendorText = "ZHONGSHAN CHIANG YU ELECTRIC CO., LTD.";
	else if (vendor == 7206) vendorText = "Shanghai Haiying Electronics Co., Ltd.";
	else if (vendor == 7207) vendorText = "SHENZHEN DNS INDUSTRIES CO., LTD.";
	else if (vendor == 7217) vendorText = "LS Cable Mtron";
	else if (vendor == 7223) vendorText = "Sonavation, Inc.";
	else if (vendor == 7229) vendorText = "NONIN MEDICAL INC.";
	else if (vendor == 7230) vendorText = "Wep Peripherals";
	else if (vendor == 7241) vendorText = "Cherng Weei Technology Corp.";
	else if (vendor == 7275) vendorText = "Philips & Lite-ON Digital Solutions Corporation";
	else if (vendor == 7276) vendorText = "Skydigital Inc.";
	else if (vendor == 7287) vendorText = "Kaetat Industrial Co., Ltd.";
	else if (vendor == 7288) vendorText = "Datascope Corp.";
	else if (vendor == 7289) vendorText = "Unigen Corporation";
	else if (vendor == 7290) vendorText = "LighTuning Technology Inc.";
	else if (vendor == 7291) vendorText = "Shenzhen Luxshare Precision Industry Co., Ltd.";
	else if (vendor == 7304) vendorText = "Somagic, Inc.";
	else if (vendor == 7305) vendorText = "HONGKONG WEIDIDA ELECTRON LIMITED";
	else if (vendor == 7310) vendorText = "ASTRON INTERNATIONAL CORP.";
	else if (vendor == 7320) vendorText = "ALPINE ELECTRONICS, INC.";
	else if (vendor == 7328) vendorText = "ACCARIO Inc.";
	else if (vendor == 7329) vendorText = "Symwave, Inc.";
	else if (vendor == 7347) vendorText = "Aces Electronics Co., Ltd.";
	else if (vendor == 7348) vendorText = "OPEX CORPORATION";
	else if (vendor == 7358) vendorText = "Texas Instruments - Stellaris";
	else if (vendor == 7359) vendorText = "FORTAT SKYMARK INDUSTRIAL COMPANY";
	else if (vendor == 7360) vendorText = "PlantSense";
	else if (vendor == 7370) vendorText = "NextWave Broadband Inc.";
	else if (vendor == 7373) vendorText = "Bodatong Technology (Shenzhen) Co., Ltd.";
	else if (vendor == 7380) vendorText = "adp corporation";
	else if (vendor == 7381) vendorText = "Firecomms Ltd.";
	else if (vendor == 7382) vendorText = "Antonio Precise Products Manufactory Ltd.";
	else if (vendor == 7390) vendorText = "Telecommunications Technology Association (TTA)";
	else if (vendor == 7391) vendorText = "WonTen Technology Co., Ltd.";
	else if (vendor == 7392) vendorText = "EDIMAX TECHNOLOGY CO., LTD.";
	else if (vendor == 7393) vendorText = "Amphenol KAE";
	else if (vendor == 7420) vendorText = "ANDES TECHNOLOGY CORPORATION";
	else if (vendor == 7421) vendorText = "Flextronics Digital Design Japan, LTD.";
	else if (vendor == 7432) vendorText = "NINGBO HENTEK DRAGON ELECTRONICS CO., LTD.";
	else if (vendor == 7433) vendorText = "TechFaith Wireless Technology Limited";
	else if (vendor == 7434) vendorText = "Johnson Controls Visteon Corporation";
	else if (vendor == 7435) vendorText = "HAN HUA CABLE & WIRE TECHNOLOGY (J.X.) CO., LTD.";
	else if (vendor == 7444) vendorText = "ALPHA-SAT TECHNOLOGY LIMITED";
	else if (vendor == 7455) vendorText = "Diostech Co., Ltd.";
	else if (vendor == 7456) vendorText = "SAMTACK INC.";
	else if (vendor == 7465) vendorText = "Horng Tong Enterprise Co., Ltd.";
	else if (vendor == 7473) vendorText = "XINTRONIX LIMITED";
	else if (vendor == 7490) vendorText = "DRAGON JOY LIMITED";
	else if (vendor == 7491) vendorText = "Montage Technology, Inc.";
	else if (vendor == 7492) vendorText = "Adirondack Digital Imaging Systems, Inc.";
	else if (vendor == 7493) vendorText = "Qisda Corporation";
	else if (vendor == 7494) vendorText = "nSys Design Systems";
	else if (vendor == 7496) vendorText = "Shenzhen XinYonghui Precise Technology Co., Ltd.";
	else if (vendor == 7497) vendorText = "SHENZHEN LINKCONN ELECTRONICS CO., LTD.";
	else if (vendor == 7501) vendorText = "Pegatron Corporation";
	else if (vendor == 7502) vendorText = "INPHI CORPORATION";
	else if (vendor == 7503) vendorText = "ADVANCED CHIP EXPRESS INC.";
	else if (vendor == 7516) vendorText = "Fresco Logic Inc.";
	else if (vendor == 7517) vendorText = "QIXING INDUSTRIAL (HK) CO.";
	else if (vendor == 7519) vendorText = "ViVOtech, Inc.";
	else if (vendor == 7520) vendorText = "ASAP International Co., Ltd.";
	else if (vendor == 7529) vendorText = "Walta Electronic Co., Ltd.";
	else if (vendor == 7530) vendorText = "ARICENT TECHNOLOGIES (HOLDINGS) LTD.";
	else if (vendor == 7531) vendorText = "The Linux Foundation";
	else if (vendor == 7537) vendorText = "Finisar Corporation";
	else if (vendor == 7542) vendorText = "LongCheng Electronic & Communication CO., LTD.";
	else if (vendor == 7543) vendorText = "Yueqing Changling Electronic Instrument Corp., Ltd.";
	else if (vendor == 7544) vendorText = "CAMBRIDGE SEMICONDUCTOR LTD.";
	else if (vendor == 7545) vendorText = "Shenzhen My-Power Technology Co., Ltd.";
	else if (vendor == 7546) vendorText = "SHINWA INTERNATIONAL HOLDINGS LTD.";
	else if (vendor == 7551) vendorText = "Ecrio";
	else if (vendor == 7552) vendorText = "PLDA";
	else if (vendor == 7553) vendorText = "YongXin Plastic & Hardware Co., Ltd.";
	else if (vendor == 7556) vendorText = "Kechenda Plastic Electronic Factory";
	else if (vendor == 7557) vendorText = "NINGBO SHUNSHENG COMMUNICATION APPARATUS CO., LTD.";
	else if (vendor == 7564) vendorText = "Wuxi AlphaScale IC Systems, Inc.";
	else if (vendor == 7582) vendorText = "CSR, Inc.";
	else if (vendor == 7583) vendorText = "KUNMING ELECTRONICS CO., LTD.";
	else if (vendor == 7584) vendorText = "Parade Technologies, Inc.";
	else if (vendor == 7607) vendorText = "SMedia Technology Corporation";
	else if (vendor == 7608) vendorText = "HD MEDICAL INC.";
	else if (vendor == 7613) vendorText = "Terawins";
	else if (vendor == 7614) vendorText = "S.R.N. Corporation";
	else if (vendor == 7615) vendorText = "Signostics Pty. Ltd.";
	else if (vendor == 7618) vendorText = "Datalogic Mobile Inc.";
	else if (vendor == 7628) vendorText = "Document Capture Technologies, Inc.";
	else if (vendor == 7629) vendorText = "HIN KUI MACHINE & METAL INDUSTRIAL CO., LTD.";
	else if (vendor == 7639) vendorText = "REDMERE TECHNOLOGY";
	else if (vendor == 7640) vendorText = "BUFFALO KOKUYO SUPPLY INC.";
	else if (vendor == 7641) vendorText = "EFFICERE TECHNOLOGIES";
	else if (vendor == 7647) vendorText = "GDA L&T Technology Services";
	else if (vendor == 7648) vendorText = "Shenzhen Excelstor Technology Ltd.";
	else if (vendor == 7649) vendorText = "Actions Microelectronics Co., Ltd.";
	else if (vendor == 7650) vendorText = "ENTERY INDUSTRIAL CO., LTD.";
	else if (vendor == 7651) vendorText = "SHENZHEN REX ELECTRONICS CO., LTD.";
	else if (vendor == 7652) vendorText = "DAEWOO ELECTRONICS CORPORATION";
	else if (vendor == 7658) vendorText = "Yesin Electronics Technology Co., Ltd.";
	else if (vendor == 7659) vendorText = "SHIUH CHI PRECISION INDUSTRY CO., LTD.";
	else if (vendor == 7665) vendorText = "HUATIANYUAN ELECTRONIC INDUSTRY CO., LTD.";
	else if (vendor == 7666) vendorText = "China Telecommunication Metrology Center of MII";
	else if (vendor == 7667) vendorText = "CRESYN CO., LTD.";
	else if (vendor == 7668) vendorText = "SHEN ZHEN FORMAN PRECISION INDUSTRY CO., LTD.";
	else if (vendor == 7680) vendorText = "Jupiter Systems";
	else if (vendor == 7682) vendorText = "GLOBEMASTER TECHNOLOGIES CO., LTD.";
	else if (vendor == 7687) vendorText = "GETA ELECTRONICS (DONG GUAN) CO., LTD.";
	else if (vendor == 7688) vendorText = "Inventure, Inc.";
	else if (vendor == 7696) vendorText = "Point Grey Research Inc.";
	else if (vendor == 7697) vendorText = "Hoya Xponent";
	else if (vendor == 7708) vendorText = "CMS PRODUCTS";
	else if (vendor == 7709) vendorText = "Kanguru Solutions";
	else if (vendor == 7711) vendorText = "INVIA";
	else if (vendor == 7712) vendorText = "JDSU";
	else if (vendor == 7722) vendorText = "NANOFORTI INC.";
	else if (vendor == 7731) vendorText = "KOBIAN CANADA INC.";
	else if (vendor == 7738) vendorText = "Continental Automotive Systems Inc.";
	else if (vendor == 7741) vendorText = "Chipsbrand Technologies (HK) Co., Limited";
	else if (vendor == 7751) vendorText = "HUNG TA H.T.ENTERPRISE CO., LTD.";
	else if (vendor == 7758) vendorText = "Etron Technology, Inc.";
	else if (vendor == 7789) vendorText = "WAN SHIH ELECTRONIC (H.K.) CO., LTD.";
	else if (vendor == 7795) vendorText = "COMLINK ELECTRONICS CO., LTD.";
	else if (vendor == 7817) vendorText = "Vtion Information Technology (Fujian) Co., Ltd.";
	else if (vendor == 7818) vendorText = "HIBEST Electronic (DongGuan) Co., Ltd.";
	else if (vendor == 7825) vendorText = "Other World Computing";
	else if (vendor == 7843) vendorText = "Concraft Holding Co., Ltd.";
	else if (vendor == 7846) vendorText = "novero GmbH";
	else if (vendor == 7863) vendorText = "WIN WIN PRECISION INDUSTRIAL CO., LTD.";
	else if (vendor == 7867) vendorText = "NuCORE Technology, Inc.";
	else if (vendor == 7879) vendorText = "Gefen Inc.";
	else if (vendor == 7881) vendorText = "MOSER BAER INDIA LIMITED";
	else if (vendor == 7898) vendorText = "AIRTIES WIRELESS NETWORKS";
	else if (vendor == 7899) vendorText = "BLACKMAGIC DESIGN PTY.";
	else if (vendor == 7923) vendorText = "JIANGXI SHIP ELECTRONICS CO., LTD.";
	else if (vendor == 7956) vendorText = "Astoria Networks GmbH";
	else if (vendor == 7976) vendorText = "Cal-Comp Electronics & Communications";
	else if (vendor == 7977) vendorText = "Analogix Semiconductor, Inc.";
	else if (vendor == 7985) vendorText = "SASKEN COMMUNICATION TECH LTD.";
	else if (vendor == 7989) vendorText = "Amphenol ShouhMin Industry (ShenZhen) Co., Ltd";
	else if (vendor == 7996) vendorText = "Chang Yang Electronics Company Ltd.";
	else if (vendor == 8009) vendorText = "ITT Corporation";
	else if (vendor == 8027) vendorText = "KYODO COMMUNICATIONS & ELECTRONICS INC.";
	else if (vendor == 8053) vendorText = "Innostor Co., Ltd.";
	else if (vendor == 8063) vendorText = "NOVA Sensors";
	else if (vendor == 8064) vendorText = "MagicPixel Inc.";
	else if (vendor == 8073) vendorText = "Dongguan Goldconn Electronics Co., Ltd.";
	else if (vendor == 8074) vendorText = "Morning Star Industrial Co., Ltd.";
	else if (vendor == 8108) vendorText = "DIFFON CORPORATION";
	else if (vendor == 8109) vendorText = "Cresta Technology Inc.";
	else if (vendor == 8116) vendorText = "Owl Computing Technologies, Inc.";
	else if (vendor == 8117) vendorText = "Siemens Unify GmbH & Co. KG";
	else if (vendor == 8137) vendorText = "NXP Semiconductors";
	else if (vendor == 8172) vendorText = "NIAN YEONG ENTERPRISE CO., LTD.";
	else if (vendor == 8181) vendorText = "Changzhou Wujin BEST Electronic Cables Co., Ltd.";
	else if (vendor == 8193) vendorText = "D-Link Corporation";
	else if (vendor == 8205) vendorText = "Belkin Electronic (Changzhou) Co., Ltd.";
	else if (vendor == 8220) vendorText = "Freeport Resources Enterprises Corp.";
	else if (vendor == 8232) vendorText = "DETAS TECHNOLOGY LTD.";
	else if (vendor == 8237) vendorText = "Snowbush IP (a division of Gennum)";
	else if (vendor == 8256) vendorText = "Hauppauge Computer Works, Inc.";
	else if (vendor == 8284) vendorText = "Shenzhen Tronixin Electronics Co., Ltd.";
	else if (vendor == 8294) vendorText = "Unicorn Electronics Components Co., Ltd.";
	else if (vendor == 8317) vendorText = "CESI Technology Co., Ltd.";
	else if (vendor == 8334) vendorText = "Luxshare-ICT-LANTO";
	else if (vendor == 8341) vendorText = "CE LINK LIMITED";
	else if (vendor == 8341) vendorText = "China Electronics Technology Limited";
	else if (vendor == 8342) vendorText = "Microconn Electronic Co., Ltd.";
	else if (vendor == 8367) vendorText = "Shenzhen CARVE Electronics Co., Ltd.";
	else if (vendor == 8382) vendorText = "BURY GmbH & Co. KG";
	else if (vendor == 8384) vendorText = "FENGHUA KINGSUN CO., LTD.";
	else if (vendor == 8386) vendorText = "Sumitomo Electric Ind., Ltd., Optical Comm. R&D Lab";
	else if (vendor == 8408) vendorText = "Changzhou Xinchao Technologies, Inc.";
	else if (vendor == 8430) vendorText = "Emotiva Audio Corp.";
	else if (vendor == 8432) vendorText = "Insight Technology Incorporated";
	else if (vendor == 8439) vendorText = "SOFTHARD XIMEA s.r.o.";
	else if (vendor == 8445) vendorText = "NOVO NORDISK A/S";
	else if (vendor == 8446) vendorText = "Elektrobit Inc.";
	else if (vendor == 8457) vendorText = "VIA Labs, Inc.";
	else if (vendor == 8492) vendorText = "Shenzhen Linoya Electronic Co., Ltd.";
	else if (vendor == 8493) vendorText = "Dong Guan City Wanhong Electric Co., Ltd.";
	else if (vendor == 8494) vendorText = "Amphenol AssembleTech (Xiamen) Co., Ltd.";
	else if (vendor == 8504) vendorText = "iVina, Inc.";
	else if (vendor == 8524) vendorText = "Y Soft Corporation";
	else if (vendor == 8550) vendorText = "JVC KENWOOD Corporation";
	else if (vendor == 8551) vendorText = "Zhejiang Fousine Science & Technology Co., Ltd.";
	else if (vendor == 8563) vendorText = "HUIZHOU HUANGJI PRECISIONS FLEX ELECTRONICAL CO., LTD.";
	else if (vendor == 8564) vendorText = "Transcend Information, Inc.";
	else if (vendor == 8565) vendorText = "Light Blue Optics, Inc.";
	else if (vendor == 8566) vendorText = "TMC/Allion Test Labs";
	else if (vendor == 8583) vendorText = "ESPACE SERVICES MULTIMEDIAS";
	else if (vendor == 8584) vendorText = "CalDigit";
	else if (vendor == 8613) vendorText = "Genesis Technology USA, Inc.";
	else if (vendor == 8618) vendorText = "TAKASAKI KYODO COMPUTING CENTER CO., LTD.";
	else if (vendor == 8627) vendorText = "Dongguan Teconn Electronics Technology Co., Ltd.";
	else if (vendor == 8629) vendorText = "SHENZHEN JASON ELECTRONICS CO., LTD.";
	else if (vendor == 8644) vendorText = "Netcom Technology (HK) Limited";
	else if (vendor == 8658) vendorText = "NeoLAB Convergence";
	else if (vendor == 8659) vendorText = "Compupack Technology Co., Ltd.";
	else if (vendor == 8660) vendorText = "Eduplayer Co., Ltd.";
	else if (vendor == 8665) vendorText = "Verification Technology, Inc.";
	else if (vendor == 8666) vendorText = "Valor Auto Companion, Inc.";
	else if (vendor == 8667) vendorText = "G-Max Technology Co., Ltd.";
	else if (vendor == 8681) vendorText = "Jiafuh Metal & Plastic (ShenZhen) Co., Ltd.";
	else if (vendor == 8682) vendorText = "JUST MAKE ELECTRONICS CO., LTD.";
	else if (vendor == 8695) vendorText = "Wuerth-Elektronik eiSos GmbH & Co. KG";
	else if (vendor == 8705) vendorText = "Elan Digital Systems Ltd.";
	else if (vendor == 8706) vendorText = "Walex Electronic (Wu Xi) Co., Ltd.";
	else if (vendor == 8707) vendorText = "Shin Shin Co., Ltd.";
	else if (vendor == 8709) vendorText = "3eYamaichi Electronics Co., Ltd.";
	else if (vendor == 8710) vendorText = "Wiretek International Investment Ltd.";
	else if (vendor == 8711) vendorText = "Fuzhou Rockchip Electronics Co., Ltd.";
	else if (vendor == 8734) vendorText = "Linktec Technologies Co., Ltd.";
	else if (vendor == 8752) vendorText = "Plugable Technologies";
	else if (vendor == 8756) vendorText = "T-CONN PRECISION CORPORATION";
	else if (vendor == 8770) vendorText = "Zhihe Electronics Technology Co., Ltd.";
	else if (vendor == 8784) vendorText = "Evernew Wire & Cable Co., Ltd.";
	else if (vendor == 8785) vendorText = "QuieTek Corp.";
	else if (vendor == 8786) vendorText = "TSANSUN TECH. CO., LTD.";
	else if (vendor == 8793) vendorText = "Skypine Electronics (Shenzhen) Co., Ltd.";
	else if (vendor == 8804) vendorText = "Entourage Systems, Inc.";
	else if (vendor == 8815) vendorText = "Koyo Trading Co., Ltd.";
	else if (vendor == 8816) vendorText = "XiaMen GaoLuChang Electronics Co. Ltd.";
	else if (vendor == 8831) vendorText = "Granite River Labs";
	else if (vendor == 8839) vendorText = "Shenzhen Oversea Win Technology Co., Ltd.";
	else if (vendor == 8840) vendorText = "Digital EMC Co., Ltd.";
	else if (vendor == 8841) vendorText = "Sun Fair Electric Wire & Cable (HK) Co., Ltd.";
	else if (vendor == 8842) vendorText = "Hotron Precision Electronic Ind. Corp.";
	else if (vendor == 8843) vendorText = "Shenzhen DLK Electronics Technology Co., Ltd.";
	else if (vendor == 8855) vendorText = "Evolution Technology Corporation";
	else if (vendor == 8873) vendorText = "Valor Communication, Inc.";
	else if (vendor == 8874) vendorText = "AppliedMicro";
	else if (vendor == 8875) vendorText = "Trigence Semiconductor, Inc.";
	else if (vendor == 8888) vendorText = "Motorola MDS Mobility Inc.";
	else if (vendor == 8889) vendorText = "eTurboTouch Technology Inc.";
	else if (vendor == 8890) vendorText = "Technology Innovation International Co., Ltd.";
	else if (vendor == 8903) vendorText = "MEMUP";
	else if (vendor == 8904) vendorText = "Karming Electronic (Shenzhen) Co., Ltd.";
	else if (vendor == 8923) vendorText = "Phase One A/S";
	else if (vendor == 8932) vendorText = "Shenyang Tongzhen Precision Electronic Technology Co.";
	else if (vendor == 8959) vendorText = "Avnet";
	else if (vendor == 8964) vendorText = "Pinnacle";
	else if (vendor == 8979) vendorText = "Kunshan Jiahua Electronics Co., Ltd.";
	else if (vendor == 8980) vendorText = "INQ Mobile Limited";
	else if (vendor == 8981) vendorText = "Avery Design Systems, Inc.";
	else if (vendor == 8982) vendorText = "DongGuan Potec Electric Industrial Co., Ltd.";
	else if (vendor == 8983) vendorText = "Huawei Device Co., Ltd.";
	else if (vendor == 8993) vendorText = "iKingdom Corp. (d.b.a. iConnectivity)";
	else if (vendor == 8998) vendorText = "CHAO KUEI MOLD INDUSTRIAL CO., LTD.";
	else if (vendor == 9008) vendorText = "Tensorcom";
	else if (vendor == 9009) vendorText = "PUZZLE LOGIC INC.";
	else if (vendor == 9028) vendorText = "HAMBURG INDUSTRIES CO., LTD.";
	else if (vendor == 9036) vendorText = "Zenverge Inc.";
	else if (vendor == 9037) vendorText = "Skype Inc.";
	else if (vendor == 9048) vendorText = "Greenconn Corporation";
	else if (vendor == 9049) vendorText = "Shenzhen Autone-Tronic Technology Co., Ltd.";
	else if (vendor == 9050) vendorText = "Top Yang Technology Enterprise Co., Ltd.";
	else if (vendor == 9051) vendorText = "KangXiang Electronic Co., Ltd.";
	else if (vendor == 9068) vendorText = "ZheJiang Chunsheng Electronics Co., Ltd.";
	else if (vendor == 9069) vendorText = "e-supplies Co., Ltd.";
	else if (vendor == 9090) vendorText = "Trigaudio, Inc.";
	else if (vendor == 9130) vendorText = "DOK (HK) Trading Limited";
	else if (vendor == 9131) vendorText = "Shenzhen Zhengtong Electronics Co., Ltd.";
	else if (vendor == 9132) vendorText = "Marunix Electron Limited";
	else if (vendor == 9147) vendorText = "EMI STOP CORP.";
	else if (vendor == 9184) vendorText = "BitifEye Digital Test Solutions GmbH";
	else if (vendor == 9216) vendorText = "Shenzhen ChuangYi Hardware Precision Mould Co., Ltd.";
	else if (vendor == 9222) vendorText = "INSIDE Secure";
	else if (vendor == 9223) vendorText = "Incasolution Co., Ltd.";
	else if (vendor == 9242) vendorText = "The Silanna Group Pty. Ltd.";
	else if (vendor == 9292) vendorText = "Minebea Co., Ltd.";
	else if (vendor == 9299) vendorText = "BAANTO";
	else if (vendor == 9300) vendorText = "Velosti Technology Limited";
	else if (vendor == 9338) vendorText = "Suzhou Jutze Technologies Co., Ltd";
	else if (vendor == 9355) vendorText = "DONGGUAN SYNCONN PRECISION INDUSTRY CO. LTD.";
	else if (vendor == 9382) vendorText = "Shenzhen Pangngai Industrial Co., Ltd.";
	else if (vendor == 9422) vendorText = "Shenzhen Deren Electronic Co., Ltd.";
	else if (vendor == 9424) vendorText = "Smith Micro Software, Inc.";
	else if (vendor == 9453) vendorText = "ZEN FACTORY GROUP (ASIA) LTD.";
	else if (vendor == 9481) vendorText = "Chain-In Electronic Co., Ltd.";
	else if (vendor == 9515) vendorText = "TOP Exactitude Industry (ShenZhen) Co., Ltd.";
	else if (vendor == 9525) vendorText = "ShenZhen Hogend Precision Technology Co., Ltd.";
	else if (vendor == 9527) vendorText = "Norel Systems Ltd.";
	else if (vendor == 9556) vendorText = "ASSA ABLOY AB";
	else if (vendor == 9589) vendorText = "Weida Hi-Tech Co., Ltd.";
	else if (vendor == 9593) vendorText = "Dongguan Wisechamp Electronic Co., Ltd.";
	else if (vendor == 9613) vendorText = "Sequans Communications";
	else if (vendor == 9636) vendorText = "ALGOLTEK, INC.";
	else if (vendor == 9642) vendorText = "Top Victory Investments Ltd. (HK)";
	else if (vendor == 9651) vendorText = "DongGuan Elinke Industrial Co., Ltd.";
	else if (vendor == 9679) vendorText = "Corning Optical Communications LLC";
	else if (vendor == 9714) vendorText = "Dongguan Jinyue Electronics Co., Ltd.";
	else if (vendor == 9723) vendorText = "RICOH IMAGING COMPANY, LTD.";
	else if (vendor == 9742) vendorText = "DongGuan HYX Industrial Co., Ltd.";
	else if (vendor == 9753) vendorText = "Advanced Silicon SA";
	else if (vendor == 9756) vendorText = "EISST Limited";
	else if (vendor == 9771) vendorText = "JXT Precision Electronics Technical Co., Ltd.";
	else if (vendor == 9779) vendorText = "Inno Audio & Video (HK) Limited";
	else if (vendor == 9797) vendorText = "Lead Data Inc.";
	else if (vendor == 9808) vendorText = "Electronics For Imaging, Inc.";
	else if (vendor == 9841) vendorText = "Innovative Logic";
	else if (vendor == 9842) vendorText = "GoPro";
	else if (vendor == 9846) vendorText = "Basler AG";
	else if (vendor == 9896) vendorText = "UNIREX CORPORATION";
	else if (vendor == 9917) vendorText = "Integral Memory Plc.";
	else if (vendor == 9973) vendorText = "Morning Star Digital Connector Co., Ltd.";
	else if (vendor == 9984) vendorText = "MITACHI CO., LTD.";
	else if (vendor == 9999) vendorText = "HGST, a Western Digital Company";
	else if (vendor == 10006) vendorText = "YUEN DA ELECTRONIC PRODUCTS FACTORY";
	else if (vendor == 10013) vendorText = "Gionee Communication Equipment Co., Ltd. ShenZhen";
	else if (vendor == 10018) vendorText = "FOOSUNG TECH";
	else if (vendor == 10022) vendorText = "Universal Electronics Inc. (dba: TVIEW)";
	else if (vendor == 10112) vendorText = "M31 Technology Corp.";
	else if (vendor == 10113) vendorText = "Liteconn Co., Ltd.";
	else if (vendor == 10121) vendorText = "Suzhou WEIJU Electronics Technology Co., Ltd.";
	else if (vendor == 10144) vendorText = "Mondokey Limited";
	else if (vendor == 10149) vendorText = "Advantest Corporation";
	else if (vendor == 10150) vendorText = "iRobot Corporation";
	else if (vendor == 10182) vendorText = "Shenzhen Huiding Technology Co. Ltd.";
	else if (vendor == 10226) vendorText = "Sibridge Tech.";
	else if (vendor == 10275) vendorText = "Dongguan Jiumutong Industry Co., Ltd.";
	else if (vendor == 10289) vendorText = "Power Integrations";
	else if (vendor == 10291) vendorText = "Oculus VR, Inc.";
	else if (vendor == 10300) vendorText = "HIGH TEK HARNESS ENTERPRISE CO., LTD.";
	else if (vendor == 10313) vendorText = "Astronics Advanced Electronic Systems Corp.";
	else if (vendor == 10316) vendorText = "Full in Hope Co., Ltd.";
	else if (vendor == 10329) vendorText = "Viconn Technology (HK) Co., Ltd.";
	else if (vendor == 10374) vendorText = "Seeed Technology Limited";
	else if (vendor == 10375) vendorText = "Specwerkz";
	else if (vendor == 10388) vendorText = "Hovercam";
	else if (vendor == 10393) vendorText = "Toptronic Industrial Co., Ltd.";
	else if (vendor == 10398) vendorText = "Esselte Leitz GmbH & Co. KG";
	else if (vendor == 10406) vendorText = "E-SEEK Inc.";
	else if (vendor == 10414) vendorText = "Zynaptic Limited";
	else if (vendor == 10423) vendorText = "Pleora Technologies Inc.";
	else if (vendor == 10431) vendorText = "Vitetech Int'l Co., Ltd.";
	else if (vendor == 10446) vendorText = "Changzhou Shi Wujin Miqi East Electronic Co., Ltd.";
	else if (vendor == 10457) vendorText = "Shenzhen Ourconn Technology Co., Ltd.";
	else if (vendor == 10466) vendorText = "Surplus Electronic Technology Co., Ltd.";
	else if (vendor == 10470) vendorText = "BIAMP SYSTEMS";
	else if (vendor == 10491) vendorText = "Shin Hwa Contech Co., Ltd.";
	else if (vendor == 10509) vendorText = "IBCONN Technologies (Shenzhen) Co., Ltd.";
	else if (vendor == 10510) vendorText = "Fugoo Inc.";
	else if (vendor == 10519) vendorText = "Pan Xin Precision Electronics Co., Ltd.";
	else if (vendor == 10530) vendorText = "Dongguan Digi-in Digital Technology Co., Ltd.";
	else if (vendor == 10540) vendorText = "GENUSION, Inc.";
	else if (vendor == 10544) vendorText = "Ineda Systems Inc.";
	else if (vendor == 10545) vendorText = "Jolla Ltd.";
	else if (vendor == 10546) vendorText = "Peraso Technologies, Inc.";
	else if (vendor == 10549) vendorText = "Nanjing Magewell Electronics Co., Ltd.";
	else if (vendor == 10560) vendorText = "Shenzhen Yiwanda Electronics Co., Ltd.";
	else if (vendor == 10575) vendorText = "Dollar Connection Ltd.";
	else if (vendor == 10590) vendorText = "Britelite Enterprises";
	else if (vendor == 10591) vendorText = "Tecvox Connectivity, LLC";
	else if (vendor == 10593) vendorText = "Miselu Inc.";
	else if (vendor == 10595) vendorText = "FingerQ Macao Commercial Offshore Limited";
	else if (vendor == 10603) vendorText = "Xacti Corporation";
	else if (vendor == 10615) vendorText = "Shenzhen Zowee Technology Co., Ltd.";
	else if (vendor == 10643) vendorText = "ADPlaus Technology Limited";
	else if (vendor == 10646) vendorText = "Unwired Technology";
	else if (vendor == 10657) vendorText = "Union Electric Plug & Connector Corp.";
	else if (vendor == 10674) vendorText = "Canova Tech";
	else if (vendor == 10685) vendorText = "Silicon Works";
	else if (vendor == 10695) vendorText = "HANRICO ANFU ELECTRONICS CO., LTD.";
	else if (vendor == 10700) vendorText = "Kodak Alaris";
	else if (vendor == 10702) vendorText = "JGR Optics Inc.";
	else if (vendor == 10703) vendorText = "Richtek Technology Corporation";
	else if (vendor == 10705) vendorText = "Binatone Electronics Int. Ltd.";
	else if (vendor == 10715) vendorText = "Shenzhen iBoard Technology Co., Ltd.";
	else if (vendor == 10718) vendorText = "Korea Electric Terminal Co., Ltd.";
	else if (vendor == 10719) vendorText = "SMIT(HK) Limited";
	else if (vendor == 10725) vendorText = "Dongguan Kechenda Electronic Technology Co., Ltd.";
	else if (vendor == 10726) vendorText = "Fengshun Peiying Electro-Acoustic Co., Ltd.";
	else if (vendor == 10749) vendorText = "Bad Elf, LLC";
	else if (vendor == 10770) vendorText = "Vreo Limited";
	else if (vendor == 10772) vendorText = "Kanex";
	else if (vendor == 10781) vendorText = "Oxford Nanopore Technologies";
	else if (vendor == 10782) vendorText = "Obsidian Technology";
	else if (vendor == 10783) vendorText = "Lucent Trans Electronics Co., Ltd.";
	else if (vendor == 10788) vendorText = "CNPLUS";
	else if (vendor == 10789) vendorText = "Fourstar Group";
	else if (vendor == 10790) vendorText = "Tragant International Co., Ltd.";
	else if (vendor == 10791) vendorText = "DongGuan LianGang Optoelectronic Technology Co., Ltd.";
	else if (vendor == 10797) vendorText = "Atrust Computer Corp.";
	else if (vendor == 10799) vendorText = "BSUN Electronics Co., Ltd.";
	else if (vendor == 10807) vendorText = "RTD Embedded Technologies, Inc.";
	else if (vendor == 10816) vendorText = "Shenzhen Choseal Industrial Co., Ltd.";
	else if (vendor == 10817) vendorText = "Canyon Semiconductor";
	else if (vendor == 10818) vendorText = "Spectra7 Microsystems Corp.";
	else if (vendor == 10821) vendorText = "Meizu Technology Co., Ltd.";
	else if (vendor == 10822) vendorText = "Hubei Yingtong Telecommunication Cable Inc.";
	else if (vendor == 10829) vendorText = "Wilder Technologies";
	else if (vendor == 10837) vendorText = "Diodes Inc.";
	else if (vendor == 10846) vendorText = "DuPont";
	else if (vendor == 10859) vendorText = "VSN Mobil";
	else if (vendor == 10878) vendorText = "VAIO Corporation";
	else if (vendor == 10879) vendorText = "Perixx Computer GmbH";
	else if (vendor == 10893) vendorText = "Keysight Technologies Inc.";
	else if (vendor == 10895) vendorText = "Manutronics Vietnam Joint Stock Company";
	else if (vendor == 10900) vendorText = "G2 Touch Co., Ltd.";
	else if (vendor == 10901) vendorText = "Flipkart Internet Pvt. Ltd.";
	else if (vendor == 10902) vendorText = "Micromax Informatics Ltd";
	else if (vendor == 10903) vendorText = "Broadway Semiconductor, Inc.";
	else if (vendor == 10904) vendorText = "Calix";
	else if (vendor == 10907) vendorText = "Doblet Inc.";
	else if (vendor == 10909) vendorText = "LawMate International Co., Ltd.";
	else if (vendor == 10910) vendorText = "SEIKO SOLUTIONS Inc.";
	else if (vendor == 10911) vendorText = "Mobelisk LLC";
	else if (vendor == 10912) vendorText = "Casco Products Corp.";
	else if (vendor == 10917) vendorText = "Pen Generations, Inc.";
	else if (vendor == 10918) vendorText = "ChengFong International Limited";
	else if (vendor == 10922) vendorText = "Virtium Technology, Inc.";
	else if (vendor == 10923) vendorText = "Field and Company LLC, dba Leef USA";
	else if (vendor == 10927) vendorText = "Xiamen Hanin Electronic Technology Co., Ltd.";
	else if (vendor == 10928) vendorText = "GM Global Technology Operations LLC";
	else if (vendor == 10929) vendorText = "Tesco Stores Ltd.";
	else if (vendor == 10931) vendorText = "Key Asic Inc.";
	else if (vendor == 10941) vendorText = "Meeteasy Technology Limited";
	else if (vendor == 10942) vendorText = "Bluink Ltd";
	else if (vendor == 10943) vendorText = "Revolabs, Inc.";
	else if (vendor == 10944) vendorText = "POWA Technologies Ltd.";
	else if (vendor == 10945) vendorText = "Lattice Semiconductor Corp";
	else if (vendor == 10947) vendorText = "Foshan Nanhai Saga Audio Equipment Co., Ltd.";
	else if (vendor == 10948) vendorText = "BlackBox Biometrics, Inc.";
	else if (vendor == 10949) vendorText = "PhotoFast Co., Ltd.";
	else if (vendor == 10957) vendorText = "Silergy Corp.";
	else if (vendor == 10958) vendorText = "Tonetron Electronic Ltd.";
	else if (vendor == 10959) vendorText = "Ruffy Controls Inc.";
	else if (vendor == 10963) vendorText = "Shenzhen Hali-Power Industrial Co., Ltd.";
	else if (vendor == 10969) vendorText = "Zound Industries International AB";
	else if (vendor == 10970) vendorText = "McCarthy Music Corp.";
	else if (vendor == 10971) vendorText = "I-PEX USA LLC";
	else if (vendor == 10972) vendorText = "Absolute USA";
	else if (vendor == 10973) vendorText = "SEE-PLUS INDUSTRIAL LTD.";
	else if (vendor == 10979) vendorText = "Jiuzhou Digital (Hong Kong) Limited";
	else if (vendor == 10988) vendorText = "Ambiq Micro, Inc.";
	else if (vendor == 10989) vendorText = "Technology Launch, LLC";
	else if (vendor == 10990) vendorText = "Adapt-IP Company";
	else if (vendor == 10991) vendorText = "Coronado Electronics, Inc.";
	else if (vendor == 10992) vendorText = "Zhejiang Yuesui Electron Stock Co., Ltd.";
	else if (vendor == 10993) vendorText = "Innovation Spring Tech, Inc.";
	else if (vendor == 10996) vendorText = "ROLI Ltd.";
	else if (vendor == 10997) vendorText = "Libratone A/S";
	else if (vendor == 10999) vendorText = "Shenzhen Hazens Automotive Electronics (SZ) Co., Ltd.";
	else if (vendor == 11000) vendorText = "Jiangsu Toppower Automotive Electronics Co., Ltd.";
	else if (vendor == 11001) vendorText = "Drapho Electronics Technology Co., Ltd.";
	else if (vendor == 11006) vendorText = "IntriCon";
	else if (vendor == 11012) vendorText = "Spark Labs, Inc.";
	else if (vendor == 11013) vendorText = "Warn Industries";
	else if (vendor == 11017) vendorText = "Shenzhen Lidacheng Technology Co., Ltd.";
	else if (vendor == 11018) vendorText = "AMICCOM Electronics Corporation";
	else if (vendor == 11022) vendorText = "Le Shi Zhi Xin Electronic Technology (Tian Jin) Limited";
	else if (vendor == 11023) vendorText = "Best Integration Technology Co., Ltd.";
	else if (vendor == 11024) vendorText = "Cardiac Insight, Inc.";
	else if (vendor == 11028) vendorText = "EverPro Technologies Company, Ltd.";
	else if (vendor == 11029) vendorText = "Rosenberger Hochfrequenztechnik";
	else if (vendor == 11030) vendorText = "Spirometrix, Inc.";
	else if (vendor == 11031) vendorText = "Jaguar Land Rover";
	else if (vendor == 11033) vendorText = "JBSignal Co.";
	else if (vendor == 11035) vendorText = "Dongguan City Sanji Electronics Co., Ltd.";
	else if (vendor == 11038) vendorText = "NFUZD Technology Inc";
	else if (vendor == 11039) vendorText = "KinnexA, Inc.";
	else if (vendor == 11042) vendorText = "Metra Electronics Corp.";
	else if (vendor == 11043) vendorText = "Red Hat, Inc.";
	else if (vendor == 11044) vendorText = "KeepKey, LLC";
	else if (vendor == 11047) vendorText = "FluxData Incorporated";
	else if (vendor == 11052) vendorText = "S1nn GmbH & Co. KG";
	else if (vendor == 11060) vendorText = "Seemahale Telecoms";
	else if (vendor == 11061) vendorText = "Assem Technology Co., Ltd.";
	else if (vendor == 11062) vendorText = "Dongguan City Jianghan Electronics Co., Ltd.";
	else if (vendor == 11063) vendorText = "Huizhou Desay SV Automotive Co., Ltd.";
	else if (vendor == 11064) vendorText = "Ningbo Rixing Electronics Co., Ltd.";
	else if (vendor == 11068) vendorText = "Technikos Sports Inc.";
	else if (vendor == 11069) vendorText = "GuangDong YuanFeng Automotive Electroics Co., Ltd.";
	else if (vendor == 11070) vendorText = "NewAE Technology Inc.";
	else if (vendor == 11071) vendorText = "ATL-SD Co., Ltd.";
	else if (vendor == 11079) vendorText = "Huizhou Aorora Science & Technology Co., Ltd.";
	else if (vendor == 11080) vendorText = "Sounding Audio Industrial Limited";
	else if (vendor == 11081) vendorText = "GECO Incorporated";
	else if (vendor == 11082) vendorText = "Yueqing Huaxin Electronic Co., Ltd.";
	else if (vendor == 11090) vendorText = "Dongguan Evermax Electronics Technology Co., Ltd.";
	else if (vendor == 11098) vendorText = "Universal Audio, Inc.";
	else if (vendor == 11100) vendorText = "B&B Exporting Limited";
	else if (vendor == 11101) vendorText = "GSL Solutions, Inc.";
	else if (vendor == 11104) vendorText = "Viking Technology";
	else if (vendor == 11111) vendorText = "Lifesize, Inc.";
	else if (vendor == 11112) vendorText = "FLEXIM - Flexible Industriemesstechnik GmbH";
	else if (vendor == 11113) vendorText = "Humax Automotive Co., Ltd.";
	else if (vendor == 11123) vendorText = "Pioneer DJ Corporation";
	else if (vendor == 11124) vendorText = "Embedded Intelligence, Inc.";
	else if (vendor == 11125) vendorText = "New Matter";
	else if (vendor == 11126) vendorText = "Shanghai Wingtech Electronic Technology Co., Ltd.";
	else if (vendor == 11127) vendorText = "Epiphan Systems Inc.";
	else if (vendor == 11130) vendorText = "Spin Master Far East Ltd.";
	else if (vendor == 11131) vendorText = "Gigaset Digital Technology (Shenzhen) Co., Ltd.";
	else if (vendor == 11132) vendorText = "Noveltek Semiconductor Corp.";
	else if (vendor == 11139) vendorText = "Silicon Line GmbH";
	else if (vendor == 11140) vendorText = "Ever Win International Corp.";
	else if (vendor == 11144) vendorText = "Socionext Inc.";
	else if (vendor == 11145) vendorText = "Ugreen Group Limited";
	else if (vendor == 11146) vendorText = "Shanghai Pateo Electronic Equipment Mfg. Co., Ltd.";
	else if (vendor == 11154) vendorText = "i-BLADES, Inc.";
	else if (vendor == 11155) vendorText = "Altia Systems Inc.";
	else if (vendor == 11156) vendorText = "ShenZhen Baoyuanda Electronics Co., Ltd.";
	else if (vendor == 11157) vendorText = "iST - Integrated Service Technology Inc.";
	else if (vendor == 11158) vendorText = "HYUNDAI MOBIS Co., Ltd.";
	else if (vendor == 11161) vendorText = "360fly, Inc.";
	else if (vendor == 11162) vendorText = "HUIZHOU CHENG SHUO HARDWARE PLASTIC CO., LTD.";
	else if (vendor == 11163) vendorText = "Zhongshan Aute Electronics Technology Co., Ltd.";
	else if (vendor == 11164) vendorText = "Guangdong King Link Industry Co., Ltd.";
	else if (vendor == 11167) vendorText = "Scietera Technologies, Inc.";
	else if (vendor == 11168) vendorText = "InVue Security Products";
	else if (vendor == 11169) vendorText = "I-Sheng Electric Wire & Cable Co., Ltd.";
	else if (vendor == 11170) vendorText = "China Daheng Group Inc Beijing Image Vision Tech Branch";
	else if (vendor == 11171) vendorText = "Shenzhen FeiTianXia Technology Ltd.";
	else if (vendor == 11172) vendorText = "Shenzhen HengJia New Energy Auto Part Co., Ltd.";
	else if (vendor == 11175) vendorText = "77 Elektronika Kft.";
	else if (vendor == 11176) vendorText = "YUDU EASON ELECTRONIC CO., LTD.";
	else if (vendor == 11181) vendorText = "XIN JI (SHENZHEN) COMPUTER PARTS CO., LTD.";
	else if (vendor == 11189) vendorText = "Silk ID Systems";
	else if (vendor == 11190) vendorText = "3D Imaging & Simulations Corp. (3DISC)";
	else if (vendor == 11191) vendorText = "Dongguan ChengXiang Industrial Co., Ltd.";
	else if (vendor == 11192) vendorText = "OCC (Zhuhai) Electronic Co., Ltd.";
	else if (vendor == 11194) vendorText = "Sinseader Electronic Co., Ltd.";
	else if (vendor == 11195) vendorText = "DONGGUAN YELLOWKNIFE Industrial Co., Ltd.";
	else if (vendor == 11197) vendorText = "RF Creations Ltd.";
	else if (vendor == 11198) vendorText = "Chengyi Semiconductors (Shanghai) Co., Ltd.";
	else if (vendor == 11199) vendorText = "Shenzhen Shinning Electronic Co., Ltd.";
	else if (vendor == 11200) vendorText = "Shenzhen WFD Electronics Co., Ltd.";
	else if (vendor == 11201) vendorText = "Dongguan Sino Syncs Industrial Co., Ltd.";
	else if (vendor == 11202) vendorText = "JNTC Co., Ltd.";
	else if (vendor == 11208) vendorText = "DONGGUAN POLIXIN ELECTRIC CO., LTD.";
	else if (vendor == 11209) vendorText = "Tama Electric (Suzhou) Co., Ltd.";
	else if (vendor == 11210) vendorText = "Exvision, Inc.";
	else if (vendor == 11216) vendorText = "mophie, LLC";
	else if (vendor == 11219) vendorText = "Dongguan ULT-unite electronic technology co., LTD";
	else if (vendor == 11220) vendorText = "JL Audio, Inc.";
	else if (vendor == 11221) vendorText = "Cable Matters Inc.";
	else if (vendor == 11222) vendorText = "CoroWare, Inc.";
	else if (vendor == 11229) vendorText = "Charm Sciences Inc.";
	else if (vendor == 11230) vendorText = "Pickering Interfaces Limited";
	else if (vendor == 11231) vendorText = "Hangzhou Hikvision Digital Technology Co., Ltd.";
	else if (vendor == 11232) vendorText = "FULLINK ELECTRONICS TECHNOLOGY (SZ) LTD";
	else if (vendor == 11233) vendorText = "AutoChips Inc.";
	else if (vendor == 11234) vendorText = "Electric Connector Technology Co., Ltd.";
	else if (vendor == 11237) vendorText = "LELTEK";
	else if (vendor == 11238) vendorText = "Dongguan KaiWin Electronics Co., Ltd.";
	else if (vendor == 11239) vendorText = "BEFS Co., Ltd.";
	else if (vendor == 11240) vendorText = "Archisite, Inc.";
	else if (vendor == 11241) vendorText = "Magneti Marelli S.p.A Electr BL";
	else if (vendor == 11246) vendorText = "Ventev Mobile";
	else if (vendor == 11247) vendorText = "Quanta Storage Inc.";
	else if (vendor == 11248) vendorText = "Tech-Top Technology Limited";
	else if (vendor == 11253) vendorText = "Shenzhen YOOBAO Technology Co., Ltd.";
	else if (vendor == 11254) vendorText = "Shenzhen Sinotek Technology Co., Ltd.";
	else if (vendor == 11255) vendorText = "KEYW";
	else if (vendor == 11256) vendorText = "Visual Land Inc.";
	else if (vendor == 11264) vendorText = "MEEM SL Ltd";
	else if (vendor == 11265) vendorText = "Dongguan Arin Electronics Technology Co., Ltd.";
	else if (vendor == 11266) vendorText = "DongGuan City JianNuo Electronics Co., Ltd.";
	else if (vendor == 12662) vendorText = "WHANAM ELECTRONICS CO., Ltd. MS division";
	else if (vendor == 13878) vendorText = "INVIBRO";
	else if (vendor == 14627) vendorText = "National Instruments";
	else if (vendor == 16700) vendorText = "Dell Inc.";
	else if (vendor == 16962) vendorText = "USB Design By Example";
	else if (vendor == 21827) vendorText = "UC-Logic Technology Corp.";
	else if (vendor == 21930) vendorText = "OnSpec Electronic Inc.";
	else if (vendor == 24576) vendorText = "TRIDENT MICROSYSTEMS (Far East) Ltd.";
	else if (vendor == 25452) vendorText = "CoreLogic, Inc.";
	else if (vendor == 27253) vendorText = "Shanghai Jujo Electronics Co., Ltd.";
	else if (vendor == 32902) vendorText = "Intel Corporation";
	else if (vendor == 32903) vendorText = "Intel Corporation";
	else if (vendor == 38672) vendorText = "Moschip Semiconductor Technology";
	else if (vendor == 60186) vendorText = "Empia Technology, Inc.";

	if (vendorText)
		return strdup(vendorText);
	else
	{
		asprintf(&vendorText, "unknown (%04x)", vendor);
		return vendorText;
	}
}
